@@ -1,6 +1,6 @@
 /* common.h
    Shared header file for the GNOMAD package
-   Copyright (C) 2001-2007 Linus Walleij
+   Copyright (C) 2001-2011 Linus Walleij
 
 This file is part of the GNOMAD package.
 
@@ -12,14 +12,13 @@ any later version.
 You should have received a copy of the GNU General Public License
 along with Yelah xmltools; see the file COPYING.  If not, write to
 the Free Software Foundation, 59 Temple Place - Suite 330,
-Boston, MA 02111-1307, USA. 
+Boston, MA 02111-1307, USA.
 
 */
 
 #ifndef COMMON_INCLUDED
-#define COMMON_INCLUDED 1
+#define COMMON_INCLUDED
 
-// #include "config.h"
 #include <stdio.h>
 #if HAVE_STRING_H
 # include <string.h>
@@ -44,12 +43,13 @@ Boston, MA 02111-1307, USA.
 #define gettext(String) (String)
 #define dgettext(Domain,String) (String)
 #define dcgettext(Domain,String,Type) (String)
-#define bindtextdomain(Domain,Directory) (Domain) 
-#define bind_textdomain_codeset(Domain,Codeset) (Codeset) 
+#define bindtextdomain(Domain,Directory) (Domain)
+#define bind_textdomain_codeset(Domain,Codeset) (Codeset)
 #endif /* ENABLE_NLS */
 
 /* The GTK library */
 #include <gtk/gtk.h>
+#include <gdk/gdk.h>
 #include <gdk/gdkkeysyms.h>
 
 /* Macros lacking in GTK+ */
@@ -79,7 +79,7 @@ Boston, MA 02111-1307, USA.
 #define GNOMAD_DIRECTORY_FOLDER_ENTRY_COLOR  "blue"
 #define GNOMAD_DIRECTORY_FOLDER_ENTRY_WEIGHT "bold"
 #define GNOMAD_DIRECTORY_FOLDER_ENTRY_STYLE  NULL
-/* 
+/*
  * Example high contrast colors and style.
  * comment these in and comment out the lines above
  * to activate a high-visibility style.
@@ -95,12 +95,7 @@ Boston, MA 02111-1307, USA.
 
 /* Globally useful structures */
 
-typedef struct OptionMenuItem {
-  const gchar *name;
-  GtkSignalFunc func;
-} OptionMenuItem;
-
-typedef struct 
+typedef struct
 {
   GtkListStore *hdliststore;
   GtkListStore *jbliststore;
@@ -112,7 +107,7 @@ typedef struct
   GList *history;
 } transfer_widgets_t;
 
-typedef struct 
+typedef struct
 {
   GtkListStore *hdliststore;
   GtkListStore *jbliststore;
@@ -125,7 +120,7 @@ typedef struct
   GList *history;
 } data_widgets_t;
 
-typedef struct 
+typedef struct
 {
   GtkTreeStore *pltreestore;
   GtkWidget *pltreeview;
@@ -155,10 +150,8 @@ gboolean volatile cancel_jukebox_operation;
 /* Global debug level variable (standard = 7) */
 gint gnomad_debug;
 
-#if GTK_CHECK_VERSION(2,6,0)
 /* A proc for hiding dialog windows */
 GCallback dispose_of_dialog_window(GtkButton * button, gpointer data);
-#endif
 
 /* THIS PROBABLY BELONGS IN A DIFFERENT HEADER.
  * THIS IS THE ONLY EXTERNAL FUNCTION DEFINED IN gnomad2.c (other than main).
