@@ -1,6 +1,6 @@
 /* data.c
    Data transferring window widgets and callbacks
-   Copyright (C) 2001 Linus Walleij
+   Copyright (C) 2001-2011 Linus Walleij
 
 This file is part of the GNOMAD package.
 
@@ -12,7 +12,7 @@ any later version.
 You should have received a copy of the GNU General Public License
 along with GNOMAD; see the file COPYING.  If not, write to
 the Free Software Foundation, 59 Temple Place - Suite 330,
-Boston, MA 02111-1307, USA. 
+Boston, MA 02111-1307, USA.
 
 */
 
@@ -22,10 +22,6 @@ Boston, MA 02111-1307, USA.
 #include "data.h"
 #include "util.h"
 
-#if !GTK_CHECK_VERSION(2,6,0)
-#include <libgnomeui/libgnomeui.h>
-#endif
-
 static GtkWidget *new_folder_dialog;
 static GtkWidget *new_folder_entry;
 
@@ -47,15 +43,6 @@ static GCallback data_from_jukebox_to_hd (GtkButton *button,
   if (metalist != NULL) {
     GtkWidget *label1, *label2, *dialog, *button, *separator;
 
-#if !GTK_CHECK_VERSION(2,6,0)
-    dialog = gnome_dialog_new(_("Transferring files from jukebox file storage"),
-			      GNOME_STOCK_BUTTON_CANCEL,
-			      NULL);
-    gnome_dialog_button_connect(GNOME_DIALOG(dialog),
-				0,
-				G_CALLBACK(cancel_jukebox_operation_click),
-				NULL);
-#else
     dialog = gtk_dialog_new_with_buttons(_("Transferring files from jukebox file storage"),
 					 NULL,
 					 0,
@@ -67,7 +54,6 @@ static GCallback data_from_jukebox_to_hd (GtkButton *button,
 		     "clicked",
 		     G_CALLBACK(cancel_jukebox_operation_click),
 		     NULL);
-#endif
     g_signal_connect_object(GTK_OBJECT(dialog),
 			    "delete_event",
 			    G_CALLBACK(gtk_widget_destroy),
@@ -78,19 +64,12 @@ static GCallback data_from_jukebox_to_hd (GtkButton *button,
     label2 = gtk_label_new("");
     progress_bar = gtk_progress_bar_new();
     separator = gtk_hseparator_new();
-#if !GTK_CHECK_VERSION(2,6,0)
-    gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(dialog)->vbox), label1, TRUE, TRUE, 0);
-    gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(dialog)->vbox), label2, TRUE, TRUE, 0);
-    gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(dialog)->vbox), separator, TRUE, TRUE, 0);
-    gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(dialog)->vbox), progress_bar, TRUE, TRUE, 0);
-#else
     gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox), label1, TRUE, TRUE, 0);
     gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox), label2, TRUE, TRUE, 0);
     gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox), separator, TRUE, TRUE, 0);
     gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox), progress_bar, TRUE, TRUE, 0);
-#endif
     gtk_widget_show_all(dialog);
-    
+
     jb2hd_data_thread_args->dialog = dialog;
     jb2hd_data_thread_args->label = label2;
     jb2hd_data_thread_args->metalist = metalist;
@@ -115,23 +94,14 @@ static GCallback data_from_hd_to_jukebox(GtkButton *button/*UNUSED*/, gpointer u
     destroy_metalist(metalist);
     return NULL;
   }
-  
+
   if (metalist != NULL) {
     GtkWidget *label1, *label2, *dialog, *button, *separator;
-#if !GTK_CHECK_VERSION(2,6,0)
-    dialog = gnome_dialog_new(_("Transferring files to jukebox file storage"),
-			      GNOME_STOCK_BUTTON_CANCEL,
-			      NULL);
-    gnome_dialog_button_connect(GNOME_DIALOG(dialog),
-				0,
-				G_CALLBACK(cancel_jukebox_operation_click),
-				NULL);
-#else
     dialog=gtk_dialog_new_with_buttons(_("Transferring files to jukebox file storage"),
 		    NULL,
 		    0,
 		    NULL);
-    
+
     button = gtk_dialog_add_button(GTK_DIALOG(dialog),
 		    GTK_STOCK_CANCEL,
 		    0);
@@ -139,7 +109,6 @@ static GCallback data_from_hd_to_jukebox(GtkButton *button/*UNUSED*/, gpointer u
 		    "clicked",
 		    G_CALLBACK(cancel_jukebox_operation_click),
 		    NULL);
-#endif
     g_signal_connect_object(GTK_OBJECT(dialog),
 			    "delete_event",
 			    G_CALLBACK(gtk_widget_destroy),
@@ -150,19 +119,12 @@ static GCallback data_from_hd_to_jukebox(GtkButton *button/*UNUSED*/, gpointer u
     label2 = gtk_label_new("");
     progress_bar = gtk_progress_bar_new();
     separator = gtk_hseparator_new();
-#if !GTK_CHECK_VERSION(2,6,0)
-    gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(dialog)->vbox), label1, TRUE, TRUE, 0);
-    gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(dialog)->vbox), label2, TRUE, TRUE, 0);
-    gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(dialog)->vbox), separator, TRUE, TRUE, 0);
-    gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(dialog)->vbox), progress_bar, TRUE, TRUE, 0);
-#else
     gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox), label1, TRUE, TRUE, 0);
     gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox), label2, TRUE, TRUE, 0);
     gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox), separator, TRUE, TRUE, 0);
     gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox), progress_bar, TRUE, TRUE, 0);
-#endif
     gtk_widget_show_all(dialog);
-    
+
     hd2jb_data_thread_args->dialog = dialog;
     hd2jb_data_thread_args->label = label2;
     hd2jb_data_thread_args->metalist = metalist;
@@ -173,6 +135,8 @@ static GCallback data_from_hd_to_jukebox(GtkButton *button/*UNUSED*/, gpointer u
   return NULL;
 }
 
+#define MAX_HISTORY 10
+
 static void add_to_history (gchar *string)
 {
   /* See if the string is already in the history */
@@ -187,8 +151,8 @@ static void add_to_history (gchar *string)
   /* Else add it */
   data_widgets.history
     = g_list_prepend (data_widgets.history, string);
-  /* Do not remember more than 5 strings */
-  while (g_list_length(history) > 5)
+  /* Do not remember more than MAX_HISTORY strings */
+  while (g_list_length(history) > MAX_HISTORY)
     {
       GList *elem;
 
@@ -198,6 +162,43 @@ static void add_to_history (gchar *string)
     }
 }
 
+static void set_popup_history(GtkWidget *combo)
+{
+  GList *history = data_widgets.history;
+
+#if GTK_CHECK_VERSION(3,0,0)
+  // Use the new combobox abstractions in 3.0 and later
+  gtk_combo_box_text_remove_all(GTK_COMBO_BOX_TEXT(combo));
+  while (history) {
+    gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(combo), history->data);
+    history = g_list_next(history);
+  }
+#else
+  // Dead ugly code for older GTK
+  static gboolean firstrun = TRUE;
+  int i;
+
+  // Blank out all 5 entries
+  if (!firstrun) {
+    for (i = 0; i < MAX_HISTORY; i++) {
+      gtk_combo_box_remove_text(GTK_COMBO_BOX(combo), 0);
+    }
+  } else {
+    firstrun = FALSE;
+  }
+
+  for (i = 0; i < MAX_HISTORY; i++) {
+    if (history) {
+      gtk_combo_box_append_text(GTK_COMBO_BOX(combo), history->data);
+      history = g_list_next(history);
+    } else {
+      gtk_combo_box_append_text(GTK_COMBO_BOX(combo), "");
+    }
+    i++;
+  }
+#endif
+}
+
 
 /* Response to the "rescan" call from the harddisk popup menu */
 static GCallback hdmenu_rescan_response(gpointer data)
@@ -219,7 +220,7 @@ static GCallback hdmenu_delete_response(gpointer data)
 {
   if (request_confirmation_dialog(_("Really delete selected files?"))) {
     GList *metalist = get_all_metadata_from_selection(HDDATA_LIST);
-    
+
     delete_files(metalist);
     remove_selected(HDDATA_LIST);
     destroy_metalist(metalist);
@@ -239,7 +240,8 @@ static void go_down(void)
     return;
   }
 
-  /* Get the size column. If this is zero, 
+  /*
+   * Get the size column. If this is zero,
    * we're dealing with a directory! Only
    * directories of size 0 are allowed, no
    * files of size 0.
@@ -250,8 +252,8 @@ static void go_down(void)
     change_directory(meta->path);
     path = get_current_dir();
     // Set the text in the box, then switch directory view
-    gtk_combo_set_popdown_strings (GTK_COMBO (combo), data_widgets.history);
-    gtk_entry_set_text (GTK_ENTRY (GTK_COMBO (combo)->entry), path);
+    set_popup_history(combo);
+    gtk_entry_set_text(GTK_ENTRY(gtk_bin_get_child(GTK_BIN(combo))), path);
     fill_in_dir(HDDATA_LIST, path);
   }
   destroy_metadata_t(meta);
@@ -266,14 +268,15 @@ static void go_down_jukebox(void)
     return;
   }
 
-  /* Get the size column. If this is zero, 
+  /*
+   * Get the size column. If this is zero,
    * we're dealing with a directory! Only
    * directories of size 0 are allowed, no
    * files of size 0.
    */
   if (meta->size == 0) {
     GtkWidget *entry = data_widgets.jbentry;
-    
+
     // g_print("Changing directory to %s\n", meta->folder);
     rebuild_datafile_list(meta->folder);
     // Set the text in the box
@@ -282,8 +285,10 @@ static void go_down_jukebox(void)
   destroy_metadata_t(meta);
 }
 
-/* If we come here, then the user has selected a row in the 
- * harddisk file listing */
+/*
+ * If we come here, then the user has selected a row in the
+ * harddisk file listing
+ */
 static GCallback hdlist_mouseevent(GtkWidget      *widget,
 				   GdkEventButton *event,
 				   gpointer        data )
@@ -293,8 +298,8 @@ static GCallback hdlist_mouseevent(GtkWidget      *widget,
     return (gpointer) 1;
   } else if (event->type == GDK_BUTTON_PRESS && event->button == 3) {
     GdkEventButton *bevent = (GdkEventButton *) event;
-    
-    gtk_menu_popup (GTK_MENU (data_widgets.harddiskpopupmenu), 
+
+    gtk_menu_popup (GTK_MENU (data_widgets.harddiskpopupmenu),
 		    NULL, NULL, NULL, NULL, bevent->button, bevent->time);
     return (gpointer) 1;
   }
@@ -305,7 +310,7 @@ static GCallback hdlist_keyevent (GtkWidget    *widget,
 				  GdkEventKey    *event,
 				  gpointer        data )
 {
-  if (event->type == GDK_KEY_PRESS && 
+  if (event->type == GDK_KEY_PRESS &&
       (event->keyval == GDK_Return || event->keyval == GDK_KP_Enter)) {
     go_down();
     return (gpointer) 1;
@@ -353,20 +358,6 @@ static GCallback jbmenu_create_folder_response(gpointer data)
 {
   GtkWidget *label, *button;
 
-#if !GTK_CHECK_VERSION(2,6,0)
-  new_folder_dialog = gnome_dialog_new(_("Create a new folder"),
-				       GNOME_STOCK_BUTTON_CANCEL,
-				       GNOME_STOCK_BUTTON_OK,
-				       NULL);
-  gnome_dialog_button_connect_object(GNOME_DIALOG(new_folder_dialog),
-				     0,
-				     GTK_SIGNAL_FUNC(gtk_widget_destroy),
-				     GTK_OBJECT(new_folder_dialog));
-  gnome_dialog_button_connect(GNOME_DIALOG(new_folder_dialog),
-			      1,
-			      GTK_SIGNAL_FUNC(create_new_folder_ok_button),
-			      NULL);
-#else
   new_folder_dialog=gtk_dialog_new_with_buttons(_("Create a new folder"),
 		  NULL,
 		  0,
@@ -377,7 +368,7 @@ static GCallback jbmenu_create_folder_response(gpointer data)
 		  0);
   g_signal_connect(button,
 		  "clicked",
-		  GTK_SIGNAL_FUNC(dispose_of_dialog_window),
+		  G_CALLBACK(dispose_of_dialog_window),
 		  GTK_OBJECT(new_folder_dialog));
 
   button = gtk_dialog_add_button(GTK_DIALOG(new_folder_dialog),
@@ -385,27 +376,18 @@ static GCallback jbmenu_create_folder_response(gpointer data)
 		  1);
   g_signal_connect(button,
 		  "clicked",
-		  GTK_SIGNAL_FUNC(create_new_folder_ok_button),
-		  NULL);	  
-#endif
+		  G_CALLBACK(create_new_folder_ok_button),
+		  NULL);
   gtk_window_set_position (GTK_WINDOW(new_folder_dialog), GTK_WIN_POS_MOUSE);
 
   label = gtk_label_new(_("Choose a name for the new folder:"));
-#if !GTK_CHECK_VERSION(2,6,0)
-  gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(new_folder_dialog)->vbox), label, TRUE, TRUE, 0);
-#else
   gtk_box_pack_start(GTK_BOX(GTK_DIALOG(new_folder_dialog)->vbox), label, TRUE, TRUE, 0);
-#endif
   gtk_widget_show(label);
   new_folder_entry = gtk_entry_new();
-#if !GTK_CHECK_VERSION(2,6,0)
-  gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(new_folder_dialog)->vbox), new_folder_entry, TRUE, TRUE, 0);
-#else
   gtk_box_pack_start(GTK_BOX(GTK_DIALOG(new_folder_dialog)->vbox), new_folder_entry, TRUE, TRUE, 0);
-#endif
   gtk_widget_show(new_folder_entry);
 
-  g_signal_connect(G_OBJECT (new_folder_dialog), 
+  g_signal_connect(G_OBJECT (new_folder_dialog),
 		   "delete_event",
 		   G_CALLBACK(gtk_widget_destroy),
 		   G_OBJECT (new_folder_dialog));
@@ -420,7 +402,7 @@ static GCallback jbmenu_delete_response(gpointer data)
 {
   if (request_confirmation_dialog(_("Really delete selected files?"))) {
     GList *metalist = get_all_metadata_from_selection(JBDATA_LIST);
-    
+
     jukebox_delete_files(metalist);
     remove_selected(JBDATA_LIST);
     destroy_metalist(metalist);
@@ -429,8 +411,10 @@ static GCallback jbmenu_delete_response(gpointer data)
 }
 
 
-/* If we come here, then the user has selected a row in the 
- * jukebox files listing */
+/*
+ * If we come here, then the user has selected a row in the
+ * jukebox files listing
+ */
 static GCallback jblist_mouseevent(GtkWidget      *clist,
 				   GdkEventButton *event,
 				   gpointer        data )
@@ -440,7 +424,7 @@ static GCallback jblist_mouseevent(GtkWidget      *clist,
     return (gpointer) 1;
   } else if (event->type == GDK_BUTTON_PRESS && event->button == 3) {
     GdkEventButton *bevent = (GdkEventButton *) event;
-    
+
     gtk_menu_popup (GTK_MENU (data_widgets.jukeboxpopupmenu),
 		    NULL, NULL, NULL, NULL, bevent->button, bevent->time);
     return (gpointer) 1;
@@ -449,11 +433,15 @@ static GCallback jblist_mouseevent(GtkWidget      *clist,
 }
 
 
-static int chdir_edit (GtkWidget * widget, gpointer data)
+static int chdir_edit(GtkWidget * widget, gpointer data)
 {
   gchar *text, *tempstr, *path;
 
-  text = (gchar *) gtk_entry_get_text (GTK_ENTRY (GTK_COMBO (data_widgets.combo)->entry));
+#if GTK_CHECK_VERSION(2,24,0)
+  text = (gchar *) gtk_combo_box_text_get_active_text(GTK_COMBO_BOX_TEXT(data_widgets.combo));
+#else
+  text = (gchar *) gtk_combo_box_get_active_text(GTK_COMBO_BOX(data_widgets.combo));
+#endif
   if ((tempstr = expand_path (text)) == NULL) {
     g_free (tempstr);
   } else
@@ -466,8 +454,8 @@ static int chdir_edit (GtkWidget * widget, gpointer data)
   change_directory(text);
   /* Set the text in the box, then switch directory view */
   path = get_current_dir();
-  gtk_combo_set_popdown_strings(GTK_COMBO(data_widgets.combo), data_widgets.history);
-  gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(data_widgets.combo)->entry), path);
+  set_popup_history(data_widgets.combo);
+  gtk_entry_set_text(GTK_ENTRY(gtk_bin_get_child(GTK_BIN(data_widgets.combo))), path);
   fill_in_dir(HDDATA_LIST, path);
   return (FALSE);
 }
@@ -481,14 +469,14 @@ static void cell_data_func (GtkTreeViewColumn *tree_column,
   metadata_t *meta = get_data_metadata_from_model(model, iter);
   if (meta->size == 0) {
     g_object_set(G_OBJECT(cell),
-		 "foreground", GNOMAD_DIRECTORY_FOLDER_ENTRY_COLOR, 
+		 "foreground", GNOMAD_DIRECTORY_FOLDER_ENTRY_COLOR,
 		 "weight", GNOMAD_DIRECTORY_FOLDER_ENTRY_WEIGHT,
 		 "style", GNOMAD_DIRECTORY_FOLDER_ENTRY_STYLE,
 		 "underline", PANGO_UNDERLINE_SINGLE,
 		 NULL);
   } else {
     g_object_set(G_OBJECT(cell),
-		 "foreground", GNOMAD_DIRECTORY_FILE_ENTRY_COLOR, 
+		 "foreground", GNOMAD_DIRECTORY_FILE_ENTRY_COLOR,
 		 "weight", GNOMAD_DIRECTORY_FILE_ENTRY_WEIGHT,
 		 "style", GNOMAD_DIRECTORY_FILE_ENTRY_STYLE,
 		 "underline", FALSE,
@@ -507,11 +495,11 @@ static GtkWidget *create_listview(GtkListStore *liststore)
 
   listview = gtk_tree_view_new_with_model (GTK_TREE_MODEL(liststore));
   gtk_tree_view_set_rules_hint(GTK_TREE_VIEW(listview), TRUE);
-  
+
   dirtextrenderer = gtk_cell_renderer_text_new ();
   textrenderer = gtk_cell_renderer_text_new ();
   g_object_set(G_OBJECT(textrenderer),
-	       "foreground", GNOMAD_DIRECTORY_FILE_ENTRY_COLOR, 
+	       "foreground", GNOMAD_DIRECTORY_FILE_ENTRY_COLOR,
 	       "weight", GNOMAD_DIRECTORY_FILE_ENTRY_WEIGHT,
 	       "style", GNOMAD_DIRECTORY_FILE_ENTRY_STYLE,
 	       "underline", FALSE,
@@ -583,9 +571,9 @@ GtkWidget *create_data_widgets(void)
 
   data_widgets.history = NULL;
   /* Just add something to the history... */
-  data_widgets.history = 
+  data_widgets.history =
     g_list_append (data_widgets.history, (gpointer) get_current_dir());
-  
+
   /* The popup menu for the harddisk files */
   popupmenu = gtk_menu_new ();
   popupmenu_item  = gtk_menu_item_new_with_label (_("Rescan jukebox"));
@@ -649,24 +637,30 @@ GtkWidget *create_data_widgets(void)
 			  0);
   gtk_widget_show (popupmenu_item);
   data_widgets.jukeboxpopupmenu = popupmenu;
-  
+
   /* Then the panel (handle in the middle) */
-  panel = gtk_hpaned_new ();
-  leftbox = gtk_hbox_new (FALSE, 0);
-  left_vbox=gtk_vbox_new(FALSE, 0);
-  combo = gtk_combo_new ();
+  panel = gtk_hpaned_new();
+  leftbox = gtk_hbox_new(FALSE, 0);
+  left_vbox = gtk_vbox_new(FALSE, 0);
+
+#if GTK_CHECK_VERSION(2,24,0)
+  // Use the new combo box type in 2.24 and later
+  combo = gtk_combo_box_text_new_with_entry();
+#else
+  combo = gtk_combo_box_entry_new_text();
+#endif
+
   data_widgets.combo = combo;
-  gtk_combo_set_case_sensitive (GTK_COMBO (combo), 1);
-  gtk_combo_set_popdown_strings (GTK_COMBO (combo), data_widgets.history);
+  set_popup_history(combo);
   gtk_box_pack_start(GTK_BOX(left_vbox), combo, FALSE, FALSE, 0);
-  g_signal_connect_object(GTK_OBJECT(GTK_COMBO(combo)->entry),
+  // signal "changed" on the combo directly will not work
+  g_signal_connect_object(GTK_OBJECT(gtk_bin_get_child(GTK_BIN(combo))),
 			  "activate",
 			  G_CALLBACK(chdir_edit),
 			  NULL,
 			  0);
-  gtk_combo_disable_activate (GTK_COMBO (combo));
-  gtk_entry_set_text (GTK_ENTRY (GTK_COMBO (combo)->entry), get_current_dir());
-  gtk_widget_show (combo);
+  gtk_entry_set_text(GTK_ENTRY(gtk_bin_get_child(GTK_BIN(combo))), get_current_dir());
+  gtk_widget_show(combo);
 
   /* Create the stores and their views */
   hdlistview = create_listview(data_widgets.hdliststore);
@@ -696,14 +690,18 @@ GtkWidget *create_data_widgets(void)
 			  0);
 
   /* Fill in and sort directory */
-  fill_in_dir(HDDATA_LIST, (gchar *) gtk_entry_get_text(GTK_ENTRY (GTK_COMBO (combo)->entry)));
+#if GTK_CHECK_VERSION(2,24,0)
+  fill_in_dir(HDDATA_LIST, (gchar *) gtk_combo_box_text_get_active_text(GTK_COMBO_BOX_TEXT(combo)));
+#else
+  fill_in_dir(HDDATA_LIST, (gchar *) gtk_combo_box_get_active_text(GTK_COMBO_BOX(combo)));
+#endif
   view_and_sort_list_store(HDDATA_LIST);
 
   /* Create a scrolled window for the harddisk files */
   scrolled_window = gtk_scrolled_window_new (NULL, NULL);
   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_window),
 				  GTK_POLICY_AUTOMATIC, GTK_POLICY_ALWAYS);
-    
+
   /* Add the CList widget to the vertical box and show it. */
   gtk_container_add(GTK_CONTAINER(scrolled_window), hdlistview);
   gtk_widget_show(hdlistview);
@@ -715,7 +713,7 @@ GtkWidget *create_data_widgets(void)
   /* A vertical box for the transfer buttons */
   transfer_button_vbox=gtk_vbox_new(FALSE, 0);
   gtk_container_set_border_width(GTK_CONTAINER(transfer_button_vbox), 5);
-  
+
   /* Add buttons to this vertical box */
   button = gtk_button_new();
   arrow = gtk_arrow_new(GTK_ARROW_RIGHT, GTK_SHADOW_NONE);
@@ -739,7 +737,7 @@ GtkWidget *create_data_widgets(void)
 			  0);
   gtk_box_pack_start(GTK_BOX(transfer_button_vbox), button, TRUE, FALSE, 0);
   gtk_widget_show(button);
-  
+
   gtk_box_pack_start(GTK_BOX(leftbox), transfer_button_vbox, FALSE, FALSE, 0);
   gtk_paned_pack1 (GTK_PANED(panel), leftbox, TRUE, TRUE);
   gtk_widget_show(leftbox);
@@ -751,7 +749,7 @@ GtkWidget *create_data_widgets(void)
   scrolled_window = gtk_scrolled_window_new (NULL, NULL);
   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_window),
 				  GTK_POLICY_AUTOMATIC, GTK_POLICY_ALWAYS);
-  
+
   /* Add the ListView widget to the vertical box and show it. */
   gtk_container_add(GTK_CONTAINER(scrolled_window), jblistview);
   gtk_widget_show(jblistview);
