@@ -1,6 +1,6 @@
 /* editmeta.c
    Edit metadata for an mp3- or similar file
-   Copyright (C) 2001 Linus Walleij
+   Copyright (C) 2001-2011 Linus Walleij
 
 This file is part of the GNOMAD package.
 
@@ -12,17 +12,11 @@ any later version.
 You should have received a copy of the GNU General Public License
 along with GNOMAD; see the file COPYING.  If not, write to
 the Free Software Foundation, 59 Temple Place - Suite 330,
-Boston, MA 02111-1307, USA. 
+Boston, MA 02111-1307, USA.
 
 */
 
 #include "common.h"
-/* The GNOME library - cannot be put in common as it
- * disturbs the id3.cpp file */
-#if !GTK_CHECK_VERSION(2,6,0)
-#include <libgnomeui/libgnomeui.h>
-#endif
-
 #include "filesystem.h"
 #include "jukebox.h"
 #include "xfer.h"
@@ -49,20 +43,6 @@ static gchar *origfname;
 static gchar *folder;
 static gchar *protect;
 
-/* Response to DELETE event (window destruction) */
-// Not actually used
-//static gint delete(GtkWidget *widget,
-//		   GtkWidget *event,
-//		   gpointer   data)
-//{
-//  if (metalist != NULL) {
-//    destroy_metalist(metalist);
-//  }
-//  metalist = NULL;
-//  gtk_grab_remove(edit_dialog);
-//  return(FALSE);
-//}
-
 static gchar *ret_nonull(gchar *retval)
 {
   if (retval == NULL) {
@@ -223,7 +203,7 @@ static void edit_ok_click ( GtkButton *button,
     if (changed) {
       /* Write the new tag */
       gchar tmp[512];
-    
+
       /* First is artist, second is title */
       sprintf(tmp, _("Updating metadata on %s - %s"), newmeta->artist, newmeta->title);
       gtk_label_set_text(GTK_LABEL(edit_dialog_msglabel), tmp);
@@ -307,7 +287,7 @@ static gboolean all_strings_same(GList *metalist, gint column)
 {
   GList *tmplist = metalist;
   gchar *firstval;
-  
+
   if (g_list_length(metalist) < 2)
     return TRUE;
   firstval = metalist_get_column(metalist, column);
@@ -328,39 +308,14 @@ static gboolean all_strings_same(GList *metalist, gint column)
 
 static void add_to_dialog(GtkWidget *dialog, GtkWidget *thing)
 {
-#if !GTK_CHECK_VERSION(2,6,0)
-  gtk_box_pack_start (GTK_BOX (GNOME_DIALOG (dialog)->vbox), thing, TRUE,
-		      TRUE, 0);
-#else
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), thing, TRUE,
 		      TRUE, 0);
-#endif
 }
 /* Editing the metadata... */
 static void edit_dialog_create(void)
 {
   GtkWidget *hbox, *label, *dialog, *tempwid, *entry;
-#if !GTK_CHECK_VERSION(2,6,0)
-  if (target == JB_LIST) {
-    dialog = gnome_dialog_new(_("Edit jukebox file metadata"),
-			      GNOME_STOCK_BUTTON_CANCEL,
-			      GNOME_STOCK_BUTTON_OK,
-			      NULL);
-  } else {
-    dialog = gnome_dialog_new(_("Edit track metadata"),
-			      GNOME_STOCK_BUTTON_CANCEL,
-			      GNOME_STOCK_BUTTON_OK,
-			      NULL);
-  }
-  gnome_dialog_button_connect_object(GNOME_DIALOG(dialog),
-				     0,
-				     G_CALLBACK(edit_cancel_click),
-				     NULL);
-  gnome_dialog_button_connect(GNOME_DIALOG(dialog),
-			      1,
-			      G_CALLBACK(edit_ok_click),
-			      NULL);
-#else
+
   if (target == JB_LIST) {
     dialog = gtk_dialog_new_with_buttons(_("Edit jukebox file metadata"),
 					 NULL, 0, NULL);
@@ -368,7 +323,7 @@ static void edit_dialog_create(void)
     dialog = gtk_dialog_new_with_buttons(_("Edit track metadata"),
 					 NULL, 0, NULL);
   }
-  
+
   tempwid = gtk_dialog_add_button(GTK_DIALOG(dialog), GTK_STOCK_CANCEL, 0);
   g_signal_connect (tempwid, "clicked",
 		    G_CALLBACK (edit_cancel_click), NULL);
@@ -376,7 +331,6 @@ static void edit_dialog_create(void)
   tempwid = gtk_dialog_add_button(GTK_DIALOG(dialog), GTK_STOCK_OK, 1);
   g_signal_connect (tempwid, "clicked",
 		    G_CALLBACK (edit_ok_click), NULL);
-#endif
   edit_dialog = dialog;
 
   /* Add the metadata edit field for the dialog box */
@@ -415,7 +369,7 @@ static void edit_dialog_create(void)
     gtk_entry_set_text(GTK_ENTRY(entry), title);
     g_free(title);
     title = (gchar *) gtk_entry_get_text(GTK_ENTRY(entry));
-    g_signal_connect(GTK_OBJECT(entry), 
+    g_signal_connect(GTK_OBJECT(entry),
 		     "changed",
 		     G_CALLBACK(entry_edit_callback),
 		     (gpointer) &title);
@@ -460,9 +414,9 @@ static void edit_dialog_create(void)
     g_free(year);
   }
   year = (gchar *) gtk_entry_get_text(GTK_ENTRY(entry));
-  g_signal_connect(GTK_OBJECT(entry), 
+  g_signal_connect(GTK_OBJECT(entry),
 		   "changed",
-		   GTK_SIGNAL_FUNC(entry_edit_callback),
+		   G_CALLBACK(entry_edit_callback),
 		   (gpointer) &year);
   /* Alignment widget for left alignments */
   gtk_widget_show(entry);
@@ -673,7 +627,7 @@ static GList *filter_for_editing(GList *metadatas, guint listtype)
   if (metadatas == NULL) {
     return NULL;
   }
-  
+
   while (tmp) {
     metadata_t *meta = (metadata_t  *) tmp->data;
     if (meta->size == 0) {
