@@ -1,6 +1,6 @@
 /* filesystem.c
    Interface to the posix (well...) file system
-   Copyright (C) 2001-2007 Linus Walleij
+   Copyright (C) 2001-2011 Linus Walleij
 
 This file is part of the GNOMAD package.
 
@@ -12,7 +12,7 @@ any later version.
 You should have received a copy of the GNU General Public License
 along with GNOMAD; see the file COPYING.  If not, write to
 the Free Software Foundation, 59 Temple Place - Suite 330,
-Boston, MA 02111-1307, USA. 
+Boston, MA 02111-1307, USA.
 
 */
 
@@ -30,13 +30,8 @@ Boston, MA 02111-1307, USA.
 #ifdef HAVE_TAGLIB
 #include "tagfile.h"
 #endif
-#if !GTK_CHECK_VERSION(2,4,0)
-#include <libgnomeui/libgnomeui.h>
-#endif
-#if GLIB_CHECK_VERSION(2,6,0)
 #include <glib.h>
 #include <glib/gstdio.h>
-#endif
 
 /* Extra includes used by this file only */
 
@@ -55,7 +50,7 @@ extern GtkWidget *main_window;
 /* Local variables */
 static gint preffd;
 
-/* 
+/*
  * Types and function to send drawing down to idle thread
  */
 
@@ -76,7 +71,7 @@ typedef struct {
 
 static gboolean draw_label(gpointer p) {
   draw_label_args_t *args = (draw_label_args_t *) p;
-  
+
   if (args != NULL) {
     if (args->label != NULL && args->text != NULL) {
       gtk_label_set_text(GTK_LABEL(args->label), args->text);
@@ -90,7 +85,7 @@ static gboolean draw_label(gpointer p) {
 
 static gboolean update_fraction(gpointer p) {
   fraction_set_args_t *args = (fraction_set_args_t *) p;
-  
+
   if (args != NULL) {
     gtk_progress_bar_set_fraction(GTK_PROGRESS_BAR(args->progress), args->fraction);
     g_free(args);
@@ -107,7 +102,7 @@ static gboolean update_metadata(gpointer p) {
     tmp = metarg->metalist;
     while (tmp) {
       metadata_t *meta;
-      
+
       meta = (metadata_t *) tmp->data;
       // g_print("Adding metadata for \"%s\" to model\n", meta->path);
       add_metadata_to_model(meta, metarg->listtype);
@@ -127,15 +122,11 @@ gboolean copy_file(gchar *source, gchar *dest)
 {
   gint f1, f2;
 
-#if !GLIB_CHECK_VERSION(2,6,0)  
-  f1 = (gint) open(source, READONLY_FLAGS, 0);
-#else
   f1 = (gint) g_open(source, READONLY_FLAGS, 0);
-#endif
   if (f1 < 0)
     return FALSE;
 
-#if !GLIB_CHECK_VERSION(2,8,0)  
+#if !GLIB_CHECK_VERSION(2,8,0)
   f2 = (gint) creat(dest, (mode_t) CREATE_FILEMODE);
 #else
   f2 = (gint) g_creat(dest, (mode_t) CREATE_FILEMODE);
@@ -144,7 +135,7 @@ gboolean copy_file(gchar *source, gchar *dest)
     guint bufsiz;
     gboolean retval = FALSE;
     gchar *buffer;
-    
+
     for (bufsiz = 0x8000; bufsiz >= 128; bufsiz >>= 1) {
       buffer = (gchar *) g_malloc(bufsiz);
     }
@@ -155,7 +146,7 @@ gboolean copy_file(gchar *source, gchar *dest)
 
     while (1) {
       register gint n;
-      
+
       n = read(f1,buffer,bufsiz);
       if (n == -1) {
 	break;
@@ -189,7 +180,7 @@ gboolean copy_file(gchar *source, gchar *dest)
 guint64 get_64bit_file_size(const gchar * const path)
 {
   struct stat sb;
-  
+
   // Get the size that we actually have now...
   if ( stat(path, &sb) == -1 ) {
     g_print("Error getting file size for \"%s\"!!\n", path);
@@ -233,7 +224,7 @@ gchar *filename_fromutf8(const gchar * const instr)
 {
 #ifndef G_OS_WIN32
   gchar *tmp;
-  
+
   if (get_prefs_force_8859()) {
     /* FIXME utf8 conversion
 	 * when the system fails to convert the fname, ask the user
@@ -389,8 +380,8 @@ static GList *get_directory_listing(gchar* base_path, gboolean anyfile)
   return filelist;
 }
 
-static GList *get_metadata_for_dirlist(GList *inlist, 
-				       listtype_t listtype, 
+static GList *get_metadata_for_dirlist(GList *inlist,
+				       listtype_t listtype,
 				       dirfill_thread_arg_t *args)
 {
   GList *metalist = NULL;
@@ -412,14 +403,14 @@ static GList *get_metadata_for_dirlist(GList *inlist,
     }
     currentfile = 0;
   }
-  
+
   filelist = inlist;
   while ((filelist != NULL) && !cancelled) {
     metadata_t *meta;
     gchar *path;
     gchar *tmp;
     gchar fileext[5];
-        
+
     meta = new_metadata_t();
     /* Full path -> ID column */
     path = filelist->data;
@@ -468,7 +459,7 @@ static GList *get_metadata_for_dirlist(GList *inlist,
       meta->codec = g_strdup(fileext);
     }
     if (listtype == HDDATA_LIST) {
-      /* 
+      /*
        * For data files, provide basic data nothing additional is needed.
        * The file extension will be used to map the apropriate transfer
        * type later.
@@ -530,19 +521,19 @@ static GList *get_metadata_for_dirlist(GList *inlist,
 	if (!strcmp(meta->codec,"MP4")) {
 	}
 #endif
-	/* 
+	/*
 	 * Gather additional information from the path and file name
-	 * if this preference is set. 
+	 * if this preference is set.
 	 */
 	if (get_prefs_detect_metadata()) {
 	  info_from_path(meta, TRUE);
 	} else {
 	  info_from_path(meta, FALSE);
 	}
-	
+
 	/* At last pad any empty fields to be <unknown>
 	 * (the way playcenter does it) */
-	
+
 	if (meta->artist == NULL)
 	  meta->artist = g_strdup("<Unknown>");
 	if (meta->title == NULL)
@@ -567,7 +558,7 @@ static GList *get_metadata_for_dirlist(GList *inlist,
 	  /* For directories: copy dirname to Artist field */
 	  gchar **tmpv;
 	  gint i;
-	  
+
 	  tmpv = g_strsplit(meta->path, G_DIR_SEPARATOR_S, 0);
 	  /* Find last component */
 	  for (i = 0; tmpv[i] != NULL; i++) {};
@@ -597,13 +588,13 @@ static GList *get_metadata_for_dirlist(GList *inlist,
 
 
 /**
- * @param args if this and the following parameter is null the call is assumed to be 
+ * @param args if this and the following parameter is null the call is assumed to be
  *        non-threaded, else it is updated and handled as if called from a thread.
  *        Else it is assumed to be called from a single-threaded context and will not
  *        display update information.
  */
-GList *get_metadata_dir(listtype_t listtype, 
-			gchar *path, 
+GList *get_metadata_dir(listtype_t listtype,
+			gchar *path,
 			dirfill_thread_arg_t *args)
 {
   GList *metalist;
@@ -633,6 +624,23 @@ GList *get_metadata_dir(listtype_t listtype,
   return metalist;
 }
 
+static gboolean call_destroy_args(gpointer data)
+{
+  dirfill_thread_arg_t *args = data;
+  GtkWidget *w = (GtkWidget *) args->dialog;
+
+  if (args == NULL)
+    return FALSE;
+
+  if (args->dialog != NULL)
+    gtk_widget_destroy(GTK_WIDGET(args->dialog));
+
+  if (args->path != NULL)
+    g_free(args->path);
+  g_free(args);
+  return FALSE;
+}
+
 static gpointer dirfill_thread(gpointer thread_args)
 {
   dirfill_thread_arg_t *args = (dirfill_thread_arg_t *) thread_args;
@@ -646,16 +654,14 @@ static gpointer dirfill_thread(gpointer thread_args)
   da = (draw_label_args_t *) g_malloc(sizeof(draw_label_args_t));
   da->label = args->label;
   da->text = g_strdup(_("Adding metadata to view"));
-  g_idle_add(draw_label, da);  
+  g_idle_add(draw_label, da);
 
   metarg = (metadata_set_args_t *) g_malloc(sizeof(metadata_set_args_t));
   metarg->listtype = args->listtype;
   metarg->metalist = metalist;
   g_idle_add(update_metadata,metarg);
 
-  g_idle_add((GSourceFunc) gtk_widget_destroy, args->dialog);
-  g_free(args->path);
-  g_free(args);
+  g_idle_add(call_destroy_args, args);
   return NULL;
 }
 
@@ -663,23 +669,13 @@ static gpointer dirfill_thread(gpointer thread_args)
  * This callback function will cancel the ongoing
  * fill-in of metadata for a certain thread.
  */
-#if GTK_CHECK_VERSION(2,4,0)
 void swapped_cancel_fillin_callback(gpointer *data)
 {
-  dirfill_thread_arg_t *args = (dirfill_thread_arg_t *) data;  
+  dirfill_thread_arg_t *args = (dirfill_thread_arg_t *) data;
 
   g_print("Cancelled scan of %s!\n", args->path);
   args->cancelled = TRUE;
 }
-#else
-void cancel_fillin_callback(GtkWidget *widget, gpointer *data)
-{
-  dirfill_thread_arg_t *args = (dirfill_thread_arg_t *) data;  
-
-  g_print("Cancelled scan of %s!\n", args->path);
-  args->cancelled = TRUE;
-}
-#endif
 
 /**
  * This will fire up a separate thread which retrieves
@@ -698,23 +694,21 @@ void fill_in_dir(listtype_t listtype, gchar *path)
   dirfill_thread_args = (dirfill_thread_arg_t *) g_malloc(sizeof(dirfill_thread_arg_t));
 
   // Create a dialog...
-#if GTK_CHECK_VERSION(2,4,0)
   dialog = gtk_message_dialog_new (GTK_WINDOW(main_window),
 				   GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
 				   GTK_MESSAGE_INFO,
 				   GTK_BUTTONS_CLOSE,
 				   (listtype == HDDATA_LIST) ? _("Getting file metadata") : _("Getting track metadata"));
-  gtk_window_set_title (GTK_WINDOW (dialog), (listtype == HDDATA_LIST) ? _("Getting file metadata") : _("Getting track metadata"));
-  gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 5);
-  gtk_box_set_homogeneous (GTK_BOX (GTK_DIALOG (dialog)->action_area), TRUE);
-  //gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_MOUSE);
+  gtk_window_set_title (GTK_WINDOW(dialog), (listtype == HDDATA_LIST) ? _("Getting file metadata") : _("Getting track metadata"));
+  gtk_box_set_spacing(GTK_BOX(GTK_DIALOG(dialog)->vbox), 5);
+  gtk_box_set_homogeneous(GTK_BOX(GTK_DIALOG(dialog)->action_area), TRUE);
   g_signal_connect_swapped(GTK_OBJECT(dialog),
 		   "delete_event",
 		   G_CALLBACK(swapped_cancel_fillin_callback),
 		   (gpointer) dirfill_thread_args);
-  g_signal_connect_swapped(GTK_OBJECT(dialog), 
+  g_signal_connect_swapped(GTK_OBJECT(dialog),
 		   "response",
-		   G_CALLBACK(swapped_cancel_fillin_callback), 
+		   G_CALLBACK(swapped_cancel_fillin_callback),
 		   (gpointer) dirfill_thread_args);
   label1 = gtk_label_new(path);
   scanlabel = gtk_label_new("");
@@ -726,32 +720,7 @@ void fill_in_dir(listtype_t listtype, gchar *path)
   gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox), metadata_progress_bar, TRUE, TRUE, 0);
   gtk_progress_bar_update(GTK_PROGRESS_BAR(metadata_progress_bar), (gfloat) 0);
   gtk_widget_show_all(dialog);
-#else
-  dialog = gnome_dialog_new((listtype == HDDATA_LIST) ? _("Getting file metadata") : _("Getting track metadata"),
-			    GNOME_STOCK_BUTTON_CANCEL,
-			    NULL);
-  gnome_dialog_button_connect(GNOME_DIALOG(dialog),
-			      0,
-			      G_CALLBACK(cancel_fillin_callback),
-			      (gpointer) dirfill_thread_args);
-  g_signal_connect(GTK_OBJECT(dialog),
-		   "delete_event",
-		   G_CALLBACK(cancel_fillin_callback),
-		   (gpointer) dirfill_thread_args);
-  label1 = gtk_label_new((listtype == HDDATA_LIST) ? _("Getting file metadata") : _("Getting track metadata"));
-  gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(dialog)->vbox), label1, TRUE, TRUE, 0);
-  label1 = gtk_label_new(path);
-  gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(dialog)->vbox), label1, TRUE, TRUE, 0);
-  scanlabel = gtk_label_new("");
-  gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(dialog)->vbox), scanlabel, TRUE, TRUE, 0);
-  separator = gtk_hseparator_new ();
-  gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(dialog)->vbox), separator, TRUE, TRUE, 0);
-  metadata_progress_bar = gtk_progress_bar_new();
-  gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(dialog)->vbox), metadata_progress_bar, TRUE, TRUE, 0);
-  gtk_progress_bar_update(GTK_PROGRESS_BAR(metadata_progress_bar), (gfloat) 0);
-  gtk_widget_show_all(dialog);
-#endif
-  
+
   dirfill_thread_args->dialog = dialog;
   dirfill_thread_args->label = scanlabel;
   dirfill_thread_args->progress = metadata_progress_bar;
@@ -803,12 +772,8 @@ gint remove_dir_contents(gchar *dir)
 	{
 	  c += remove_dir_contents(current_file);
 	}
-      
-#if !GLIB_CHECK_VERSION(2,6,0)
-      c += remove(current_file);
-#else
+
       c += g_remove(current_file);
-#endif
       g_free(current_file);
     }
 
@@ -841,16 +806,12 @@ gint delete_files(GList *filelist)
       tmplist = tmplist->next;
       continue;
     }
-    
+
     if (g_file_test(tmp, G_FILE_TEST_IS_DIR)) {
       remove_dir_contents(tmp);
     }
 
-#if !GLIB_CHECK_VERSION(2,6,0)
-    c += remove(tmp);
-#else
     c += g_remove(tmp);
-#endif
 
     g_free(tmp);
     tmplist = tmplist->next;
@@ -859,8 +820,8 @@ gint delete_files(GList *filelist)
 }
 
 /* Copy a file and remove the tag */
-gboolean clone_and_strip_tag(const gchar * const source, 
-			     const gchar * const dest, 
+gboolean clone_and_strip_tag(const gchar * const source,
+			     const gchar * const dest,
 			     const gchar * const codec)
 {
   gchar *tmpsource, *tmpdest;
@@ -906,28 +867,22 @@ gint get_prefsfile_fd(gboolean write)
     path = stringcat(path, tmp);
     g_free(tmp);
   }
+
   if (write) {
-#if !GLIB_CHECK_VERSION(2,6,0)
-    preffd = (gint) open(path, WRITEONLY_FLAGS, (mode_t) CREATE_FILEMODE);
-#else
     preffd = (gint) g_open(path, WRITEONLY_FLAGS, (mode_t) CREATE_FILEMODE);
-#endif
     if (preffd < 0)
 #if !GLIB_CHECK_VERSION(2,8,0)
       preffd = (gint) creat(path, (mode_t) CREATE_FILEMODE);
 #else
       preffd = (gint) g_creat(path, (mode_t) CREATE_FILEMODE);
 #endif
-  }
-  else
-#if !GLIB_CHECK_VERSION(2,6,0)
-    preffd = (gint) open(path, READONLY_FLAGS, 0);
-#else
+  } else {
     preffd = (gint) g_open(path, READONLY_FLAGS, 0);
-#endif
-  if (preffd < 0 &&
-      write)
+  }
+
+  if (preffd < 0 && write) {
     create_error_dialog(_("Could not write preference file"));
+  }
   return preffd;
 }
 
@@ -1054,11 +1009,7 @@ gboolean test_writeable(gchar *path)
   FILE *file;
 
   /* Test to know if we can write into the file */
-#if !GLIB_CHECK_VERSION(2,6,0)
-  file = fopen(path,READPLUS_FOPEN_STRING);
-#else
   file = (FILE *) g_fopen(path,READPLUS_FOPEN_STRING);
-#endif
   if (file == NULL) {
     return FALSE;
   }
@@ -1068,11 +1019,7 @@ gboolean test_writeable(gchar *path)
 
 gboolean create_directory(gchar *path)
 {
-#if !GLIB_CHECK_VERSION(2,6,0)
-  if (mkdir(path, CREATE_DIRMODE) == -1) {
-#else
   if (g_mkdir(path, CREATE_DIRMODE) == -1) {
-#endif
     return FALSE;
   } else {
     return TRUE;
@@ -1089,7 +1036,7 @@ void create_dirs(gchar *filename) {
   for (dirs=0; tmpv[dirs]; ++dirs);
   if (--dirs < 1)
     goto out;
-  
+
   path = g_strdup(tmpv[0]);
   for (i=0;;) {
     gchar *tmp;
@@ -1118,11 +1065,7 @@ void export_playlistfile(gchar *filename, gchar *formatstring, GList *playlist,
   GList *tmp;
   guint i;
 
-#if !GLIB_CHECK_VERSION(2,6,0)
-  fd = (gint) open(tmpname, WRITEONLY_FLAGS, (mode_t) CREATE_FILEMODE);
-#else
   fd = (gint) g_open(tmpname, WRITEONLY_FLAGS, (mode_t) CREATE_FILEMODE);
-#endif
   if (fd < 0)
 #if !GLIB_CHECK_VERSION(2,8,0)
     fd = (gint) creat(tmpname, (mode_t) CREATE_FILEMODE);
@@ -1168,7 +1111,7 @@ void export_playlistfile(gchar *filename, gchar *formatstring, GList *playlist,
     g_free(row);
     i++;
   }
-  
+
   if (plsfile) {
     gchar *footer = g_strdup_printf("NumberOfEntries=%u\nVersion=2\n", i-1);
     write(fd, footer, strlen(footer));
