@@ -1,6 +1,6 @@
 /* id3read.c
    interface for the id3tag library
-   Copyright (C) 2001 Linus Walleij
+   Copyright (C) 2001-2011 Linus Walleij
 
 This file is part of the GNOMAD package.
 
@@ -12,7 +12,7 @@ any later version.
 You should have received a copy of the GNU General Public License
 along with GNOMAD; see the file COPYING.  If not, write to
 the Free Software Foundation, 59 Temple Place - Suite 330,
-Boston, MA 02111-1307, USA. 
+Boston, MA 02111-1307, USA.
 
 */
 
@@ -28,17 +28,15 @@ Boston, MA 02111-1307, USA.
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
-#if GLIB_CHECK_VERSION(2,6,0)	/* perhaps only needed in this case?? */
-#   include <glib.h>
-#   include <glib/gstdio.h>
-#endif
+#include <glib.h>
+#include <glib/gstdio.h>
 
 /* Eventually make charset selectable */
 
 static id3_utf8_t *charset_to_utf8(const id3_latin1_t *str)
 {
   id3_utf8_t *tmp;
-   
+
  tmp = (id3_utf8_t *) g_convert((gchar *) str,-1,"UTF-8","ISO-8859-1",NULL,NULL,NULL);
   return (id3_utf8_t *) tmp;
 }
@@ -52,11 +50,11 @@ static id3_latin1_t *charset_from_utf8(const id3_utf8_t *str)
 }
 
 /*
- * This function checks if a RIFF header exists at the beginning of 
+ * This function checks if a RIFF header exists at the beginning of
  * the *data buffer. In that case its size is returned. The size
  * of the *data buffer must be supplied.
  */
-static guint riff_header_size(gchar *data, guint bufsize) 
+static guint riff_header_size(gchar *data, guint bufsize)
 {
   guint retsize = 0;
 
@@ -585,12 +583,7 @@ remove_or_add_tag(gboolean add, gchar *path, guchar *v2tag, guint v2taglen, guch
     return;
   }
 
-#if GLIB_CHECK_VERSION(2,6,0)  
   f1 = (gint) g_open(tmppath, READONLY_FLAGS, 0);
-#else
-  f1 = (gint) open(tmppath, READONLY_FLAGS, 0);  
-#endif
-
   if (f1 < 0) {
     g_print("Could not open file f1 in remove_or_add_tag()\n");
     g_free(tmppath);
@@ -777,7 +770,7 @@ remove_or_add_tag(gboolean add, gchar *path, guchar *v2tag, guint v2taglen, guch
     if (gnomad_debug != 0) {
       g_print("Copying the file back...\n");
     }
-#if GLIB_CHECK_VERSION(2,8,0)  
+#if GLIB_CHECK_VERSION(2,8,0)
     f3 = (gint) g_creat(tmppath, (mode_t) CREATE_FILEMODE);
 #else
     f3 = (gint) creat(tmppath, (mode_t) CREATE_FILEMODE);
@@ -786,7 +779,7 @@ remove_or_add_tag(gboolean add, gchar *path, guchar *v2tag, guint v2taglen, guch
       // g_print("Creat() on original file succeeded...\n");
       while (1) {
 	register gint n;
-	
+
 	n = read(f2,buffer,bufsiz);
 	if (n == -1) {
 	  g_print("Error reading source file during final copying in remove_or_add_tag()\n");
@@ -806,11 +799,7 @@ remove_or_add_tag(gboolean add, gchar *path, guchar *v2tag, guint v2taglen, guch
     }
     close(f2);
     // g_print("Deleting %s\n", template);
-#if GLIB_CHECK_VERSION(2,6,0)  
     g_unlink(template);
-#else
-    unlink(template);
-#endif
   } else {
     // In case we couldn't open f2
     close(f1);
