@@ -112,7 +112,7 @@ void jukebox_delete_playlist(guint32 plid);
 void jukebox_rename_playlist(guint32 plid, gchar *name, 
 			     GtkTreeStore *pltreestore);
 void add_tracks_to_playlists(GList *playlists, GList *metalist);
-void build_playlist_tree(GtkTreeStore *pltreestore);
+void build_playlist_tree(void);
 guint jukebox_randomize_playlist(guint playlist, GtkTreeStore *pltreestore);
 guint jukebox_delete_track_from_playlist(guint32 trackid, guint32 plist, GtkTreeStore *pltreestore);
 gchar *jukebox_get_ownerstring(void);
