@@ -1,6 +1,6 @@
 /* metadata.c
    Metadata list stores and handler functions
-   Copyright (C) 2001 Linus Walleij
+   Copyright (C) 2001-2011 Linus Walleij
 
 This file is part of the GNOMAD package.
 
@@ -12,7 +12,7 @@ any later version.
 You should have received a copy of the GNU General Public License
 along with GNOMAD; see the file COPYING.  If not, write to
 the Free Software Foundation, 59 Temple Place - Suite 330,
-Boston, MA 02111-1307, USA. 
+Boston, MA 02111-1307, USA.
 
 */
 
@@ -354,36 +354,17 @@ get_store(listtype_t listtype)
 GtkTreeSelection *get_metadata_selection(listtype_t listtype)
 {
   GtkTreeSelection *select = NULL;
-  
+
   select = gtk_tree_view_get_selection(get_view(listtype));
   return select;
 }
 
-#if ! GTK_CHECK_VERSION(2,2,0)
-// this function sucks, but it's needed to be compatible with gtk2.0
-void multipleSelectionHelper(GtkTreeModel *model,
-			     GtkTreePath *path,
-			     GtkTreeIter *iter,
-			     gpointer data)
-{
-  GList **list;
-  list = (GList**)data;
-  *list = g_list_append(*list, gtk_tree_path_copy(path));
-}
-#endif
-
 /* Returns the paths for all selected rows so they may be processed */
 static GList *get_metadata_selection_paths(listtype_t listtype)
 {
   GtkTreeSelection *select = get_metadata_selection(listtype);
   GtkTreeModel *model = GTK_TREE_MODEL(get_store(listtype));
-#if GTK_CHECK_VERSION(2,2,0)
   GList *selectlist = gtk_tree_selection_get_selected_rows(select, &model);
-#else
-  GList *selectlist = NULL;
-  gtk_tree_selection_selected_foreach(select, multipleSelectionHelper,
-				      &selectlist);
-#endif
 
   return selectlist;
 }
@@ -392,7 +373,7 @@ GList *get_all_metadata_from_selection(listtype_t listtype)
 {
   GtkTreeSelection *select;
   GList *metadatas = NULL;
-  
+
   select = get_metadata_selection(listtype);
   if (select == NULL)
     return NULL;
@@ -907,7 +888,7 @@ void view_and_sort_list_store(listtype_t listtype)
   /* All should be found now */
   gtk_tree_view_set_model (GTK_TREE_VIEW (get_view(listtype)),
                            GTK_TREE_MODEL (get_store(listtype)));
-  
+
   if (listtype == HD_LIST) {
     for (i = TRACKLIST_ARTIST_COLUMN; i < TRACKLIST_ARTIST_COLUMN + TRACKLIST_N_COLUMNS; i++) {
       gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(transfer_widgets.hdliststore),
