@@ -1,6 +1,6 @@
 /* mp3file.c
    Accessing the metadata of a raw MPEG stream
-   Copyright (C) 2001 Linus Walleij
+   Copyright (C) 2001-2011 Linus Walleij
 
 This file is part of the GNOMAD package.
 
@@ -12,7 +12,7 @@ any later version.
 You should have received a copy of the GNU General Public License
 along with GNOMAD; see the file COPYING.  If not, write to
 the Free Software Foundation, 59 Temple Place - Suite 330,
-Boston, MA 02111-1307, USA. 
+Boston, MA 02111-1307, USA.
 
 */
 
@@ -20,10 +20,8 @@ Boston, MA 02111-1307, USA.
 #include "common.h"
 #include "util.h"
 #include "filesystem.h"
-#if GTK_CHECK_VERSION(2,6,0)  
-#   include <glib.h>
-#   include <glib/gstdio.h>
-#endif
+#include <glib.h>
+#include <glib/gstdio.h>
 
 /*
  * The following code is extracted from gtkpod, which in turn
@@ -396,12 +394,7 @@ static mp3info *mp3file_get_info (gchar *filename)
   if (gnomad_debug != 0) {
     g_print("entered mp3file_get_info()\n");
   }
-  
-#if !GTK_CHECK_VERSION(2,6,0)  
-  if ( !( fp = fopen(filename,READONLY_FOPEN_STRING) ) ) {
-#else
   if ( !( fp = g_fopen(filename,READONLY_FOPEN_STRING) ) ) {
-#endif
     g_print(("Error opening MP3 file '%s'\n"),filename);
   } else {
     mp3 = g_malloc0 (sizeof (mp3info));
@@ -941,13 +934,9 @@ static guint get_track_time_file(FILE * file)
 static guint get_track_time (gchar *path)
 {
   guint result = 0;
-  
+
   if (path) {
-#if !GTK_CHECK_VERSION(2,6,0)  
-    FILE *file = fopen (path, READONLY_FOPEN_STRING);
-#else
     FILE *file = g_fopen (path, READONLY_FOPEN_STRING);
-#endif
     result = get_track_time_file (file);
     if (file) fclose (file);
   }
