@@ -1,6 +1,6 @@
 /* player.c
    Player window for jukebox file playing
-   Copyright (C) 2001 Linus Walleij
+   Copyright (C) 2001-2011 Linus Walleij
 
 This file is part of the GNOMAD package.
 
@@ -12,7 +12,7 @@ any later version.
 You should have received a copy of the GNU General Public License
 along with GNOMAD; see the file COPYING.  If not, write to
 the Free Software Foundation, 59 Temple Place - Suite 330,
-Boston, MA 02111-1307, USA. 
+Boston, MA 02111-1307, USA.
 
 */
 
@@ -39,11 +39,8 @@ static void patch_changed (gpointer combo,
   GSList *tmplist;
   gboolean was_exclusive = FALSE;
   guint effect = GPOINTER_TO_UINT(data);
-#if ! GTK_CHECK_VERSION(2,4,0)
-  guint patch = gtk_option_menu_get_history(GTK_OPTION_MENU(combo));
-#else
   guint patch = gtk_combo_box_get_active(GTK_COMBO_BOX(combo));
-#endif
+
   // See if it is exclusive
   tmplist = exclusive_patches;
   while (tmplist != NULL) {
@@ -59,22 +56,14 @@ static void patch_changed (gpointer combo,
     while (tmplist != NULL) {
       if (combo != tmplist->data) {
 	// Reset it
-#if ! GTK_CHECK_VERSION(2,4,0)
-	gtk_option_menu_set_history(GTK_OPTION_MENU(tmplist->data), 0);
-#else
 	gtk_combo_box_set_active(GTK_COMBO_BOX(tmplist->data), 0);
-#endif
       }
       tmplist = g_slist_next(tmplist);
     }
     // Then make sure it is set
-#if ! GTK_CHECK_VERSION(2,4,0)
-    gtk_option_menu_set_history(GTK_OPTION_MENU(combo), patch);
-#else
     gtk_combo_box_set_active(GTK_COMBO_BOX(combo), patch);
-#endif
   }
-  
+
   if (playing) {
     // Wire scalevalue to 0
     // g_print("Selecting patch %d for effect %04X\n", patch, effect);
@@ -85,7 +74,6 @@ static void patch_changed (gpointer combo,
 
 /* options = name -> value -> name -> value -> ... */
 /* This code for GTK+ 2.3 / 2.4 and up */
-#if GTK_CHECK_VERSION(2,4,0)
 static GtkWidget *create_patch_menu(guint16 effect,
 				    GSList *patches,
 				    GCallback callback_function,
@@ -119,54 +107,6 @@ static GtkWidget *create_patch_menu(guint16 effect,
   g_slist_free(patches);
   return combo_box;
 }
-#else
-/* options = name -> value -> name -> value -> ... */
-static GtkWidget *create_patch_menu(guint16 effect,
-				    GSList *patches,
-				    GCallback callback_function,
-				    guint default_patch)
-{
-  GtkWidget *option_menu;
-  GtkWidget *menu;
-  GtkWidget *menu_item;
-  GSList *group = NULL;
-  GSList *tmplist = patches;
-  guint i;
-  guint mr_effect = (guint) effect;
-
-  // Create an option menu
-  option_menu = gtk_option_menu_new();
-  menu = gtk_menu_new();
-  // Add rows to the menu
-  i = 0;
-  while (tmplist) {
-    menu_item = gtk_radio_menu_item_new_with_label(group, tmplist->data);
-    if (i == default_patch) {
-      gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(menu_item), TRUE);
-    }
-    group = gtk_radio_menu_item_get_group(GTK_RADIO_MENU_ITEM(menu_item));
-    gtk_menu_shell_append(GTK_MENU_SHELL(menu), menu_item);
-    gtk_widget_show(menu_item);
-    tmplist = tmplist->next;
-    i++;
-  }
-  g_signal_connect(GTK_OBJECT(option_menu),
-		   "changed",
-		   G_CALLBACK(callback_function),
-		   GUINT_TO_POINTER(mr_effect));
-  gtk_option_menu_set_menu (GTK_OPTION_MENU (option_menu), menu);
-  gtk_option_menu_set_history (GTK_OPTION_MENU (option_menu), default_patch);
-  gtk_widget_show(option_menu);
-  // Free memory used by list
-  tmplist = patches;
-  while (tmplist != NULL) {
-    g_free(tmplist->data);
-    tmplist = tmplist->next;
-  }
-  g_slist_free(patches);
-  return option_menu;
-}
-#endif
 
 void prevbutton_click ( GtkButton *button,
 			gpointer data )
@@ -199,7 +139,7 @@ static void adjust_scalevalue (GtkAdjustment *adj,
   gint16 scalevalue = (gint16) adj->value;
 
   if (playing) {
-    //g_print("Setting scalevalue for effect %04X to %d\n", 
+    //g_print("Setting scalevalue for effect %04X to %d\n",
     //  adjprops->effect, scalevalue);
     jukebox_adjust_eax(adjprops->effect, 0, scalevalue);
   }
@@ -223,7 +163,7 @@ static GtkWidget *create_adjustment_control(guint16 effect,
   GtkWidget *vscale;
   eax_adjust_props_t *adjprops;
 
-  adjprops = (eax_adjust_props_t *) g_malloc(sizeof(eax_adjust_props_t)); 
+  adjprops = (eax_adjust_props_t *) g_malloc(sizeof(eax_adjust_props_t));
   adjprops->effect = effect;
   adjprops->min = min;
   adjprops->max = max;
@@ -263,7 +203,7 @@ static void toggle_onoff (GtkCheckButton *toggle,
   gboolean togglestatus;
   guint16 onoff;
   guint effect = GPOINTER_TO_UINT(data);
-  
+
   togglestatus = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(toggle));
   if (togglestatus)
     onoff = 1;
@@ -272,7 +212,7 @@ static void toggle_onoff (GtkCheckButton *toggle,
   if (playing) {
     // Wire scalevalue to 0
     jukebox_adjust_eax(effect, onoff, 0);
-  } 
+  }
 }
 
 
@@ -299,7 +239,7 @@ static GtkWidget *get_eax_controls(void)
   hbox = gtk_hbox_new(FALSE, 5);
 
   jukebox_reset_get_eax();
-  
+
   while ((eax = jukebox_get_eax()) != NULL) {
     // FIXME: reset all exclusive effects when an exclusive is selected.
     // Eax group has its own box
@@ -347,13 +287,13 @@ static GtkWidget *get_eax_controls(void)
 	guint i;
 	GSList *names = NULL;
 	GtkWidget *patches;
-	
+
 	for(i = 0; i < eax->max_value - eax->min_value + 1; i++) {
 	  names = g_slist_append(names, g_strdup(eax->option_names[i]));
 	}
 	patches = create_patch_menu(eax->number,
 				    names,
-				    GTK_SIGNAL_FUNC(patch_changed),
+				    G_CALLBACK(patch_changed),
 				    eax->current_value);
 	gtk_box_pack_start(GTK_BOX(vbox), patches, TRUE, TRUE, 0);
 	if (eax->exclusive) {
@@ -364,7 +304,7 @@ static GtkWidget *get_eax_controls(void)
       // Scale value slider
       if (eax->type == NJB_EAX_SLIDER_CONTROL) {
 	GtkWidget *slider;
-	
+
 	// g_print("Scalevalue %s, min %d, max %d, current %d\n",
 	//	eax->name, eax->min_scalevalue, eax->max_scalevalue,
 	//	eax->current_scalevalue);
@@ -385,7 +325,7 @@ static GtkWidget *get_eax_controls(void)
   // Pack the last group box
   gtk_box_pack_start(GTK_BOX(hbox), group_box, TRUE, TRUE, 0);
   gtk_widget_show(group_box);
-  
+
   return hbox;
 }
 
@@ -398,7 +338,7 @@ static void adjust_position (GtkAdjustment *adj,
   // Calculate the byte position offset
   guint delta = 0;
   guint skipto = 0;
-  
+
   // If we just passed a track boundary there is no delta,
   // else we find out how much the position has changed.
   if ((prevpos == 100 || prevpos == 99) && (pos == 0  || pos == 1)) {
@@ -435,10 +375,6 @@ void create_player_window(GList *metalist)
   GtkWidget *label1, *label2, *label3, *dialog, *button, *separator;
   GtkWidget *hscale, *eax_controls;
   GtkWidget *hbox, *hbox2, *vbox;
-#if !GTK_CHECK_VERSION(2,6,0)
-  GtkWidget *label, *arrow;
-  GtkWidget *hbox3;
-#endif
   GtkAdjustment *adj;
 
   // Playback on MTP devices not supported. (Yet.)
@@ -448,10 +384,10 @@ void create_player_window(GList *metalist)
   }
   play_thread_args.metalist = metalist;
   dialog = gtk_dialog_new();
-  gtk_window_set_title (GTK_WINDOW (dialog), (_("Playing tracks on the jukebox")));
-  gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 5);
-  gtk_box_set_homogeneous (GTK_BOX (GTK_DIALOG (dialog)->action_area), TRUE);
-  gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_MOUSE);
+  gtk_window_set_title(GTK_WINDOW (dialog), (_("Playing tracks on the jukebox")));
+  gtk_box_set_spacing(GTK_BOX (GTK_DIALOG (dialog)->vbox), 5);
+  gtk_box_set_homogeneous(GTK_BOX (GTK_DIALOG (dialog)->action_area), TRUE);
+  gtk_window_set_position(GTK_WINDOW (dialog), GTK_WIN_POS_MOUSE);
 
   label1 = gtk_label_new(_("Playing:"));
   label2 = gtk_label_new("");
@@ -476,14 +412,10 @@ void create_player_window(GList *metalist)
   gtk_scale_set_value_pos (GTK_SCALE(hscale), GTK_POS_TOP);
   gtk_scale_set_draw_value (GTK_SCALE(hscale), FALSE);
   gtk_widget_show (hscale);
-#if GTK_CHECK_VERSION(2,6,0)
   button =  gtk_button_new_from_stock(GTK_STOCK_MEDIA_STOP);
-#else
-  button = gtk_button_new_with_label(_("STOP"));
-#endif
-  GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->action_area), button,
-		      FALSE, FALSE, 0);
+  gtk_widget_set_can_default(button, TRUE);
+  gtk_box_pack_start(GTK_BOX (GTK_DIALOG (dialog)->action_area), button,
+		     FALSE, FALSE, 0);
   g_signal_connect_object(GTK_OBJECT(button),
 			  "clicked",
 			  G_CALLBACK(stop_playing),
@@ -506,46 +438,24 @@ void create_player_window(GList *metalist)
   /* Manouver panel */
   hbox2 = gtk_hbox_new(FALSE, 0);
 
-#if GTK_CHECK_VERSION(2,6,0)
   button =  gtk_button_new_from_stock(GTK_STOCK_MEDIA_PREVIOUS);
-#else
-  button = gtk_button_new();
-  hbox3 = gtk_hbox_new(FALSE, 0);
-  arrow = gtk_arrow_new(GTK_ARROW_LEFT, GTK_SHADOW_NONE);
-  gtk_box_pack_start(GTK_BOX(hbox3), arrow, TRUE, TRUE, 0);
-  label = gtk_label_new(_("PREV"));
-  gtk_box_pack_start(GTK_BOX(hbox3), label, TRUE, TRUE, 0);
-  gtk_widget_show(arrow);
-  gtk_container_add(GTK_CONTAINER(button), hbox3);
-#endif
   g_signal_connect_object(GTK_OBJECT(button),
 			  "clicked",
 			  G_CALLBACK(prevbutton_click),
 			  NULL,
 			  0);
   gtk_box_pack_start(GTK_BOX(hbox2), button, FALSE, TRUE, 0);
-  GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
+  gtk_widget_set_can_default(button, TRUE);
   label3 = gtk_label_new("00:00:00");
   gtk_box_pack_start(GTK_BOX(hbox2), label3, TRUE, TRUE, 0);
-#if GTK_CHECK_VERSION(2,6,0)
   button =  gtk_button_new_from_stock(GTK_STOCK_MEDIA_NEXT);
-#else
-  button = gtk_button_new();
-  hbox3 = gtk_hbox_new(FALSE, 0);
-  label = gtk_label_new(_("NEXT"));
-  gtk_box_pack_start(GTK_BOX(hbox3), label, TRUE, TRUE, 0);
-  arrow = gtk_arrow_new(GTK_ARROW_RIGHT, GTK_SHADOW_NONE);
-  gtk_box_pack_start(GTK_BOX(hbox3), arrow, TRUE, TRUE, 0);
-  gtk_widget_show(arrow);
-  gtk_container_add(GTK_CONTAINER(button), hbox3);
-#endif
   g_signal_connect_object(GTK_OBJECT(button),
 			  "clicked",
 			  G_CALLBACK(nextbutton_click),
 			  NULL,
 			  0);
   gtk_box_pack_start(GTK_BOX(hbox2), button, FALSE, TRUE, 0);
-  GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
+  gtk_widget_set_can_default(button, TRUE);
   gtk_box_pack_start(GTK_BOX(vbox), hbox2, FALSE, TRUE, 0);
 
   separator = gtk_hseparator_new ();
@@ -561,7 +471,7 @@ void create_player_window(GList *metalist)
   play_thread_args.timelabel = label3;
   play_thread_args.adj = adj;
   play_thread_args.dialog = dialog;
-  
+
   cancel_jukebox_operation = FALSE;
   g_thread_create(play_thread,(gpointer) &play_thread_args, FALSE, NULL);
   playing = TRUE;
