@@ -1,6 +1,6 @@
 /* playlists.c
    Playlist GUI and call handling
-   Copyright (C) 2001-2003 Linus Walleij
+   Copyright (C) 2001-2011 Linus Walleij
 
 This file is part of the GNOMAD package.
 
@@ -12,7 +12,7 @@ any later version.
 You should have received a copy of the GNU General Public License
 along with GNOMAD; see the file COPYING.  If not, write to
 the Free Software Foundation, 59 Temple Place - Suite 330,
-Boston, MA 02111-1307, USA. 
+Boston, MA 02111-1307, USA.
 
 */
 
@@ -24,12 +24,6 @@ Boston, MA 02111-1307, USA.
 #include "prefs.h"
 #include "filesystem.h"
 
-#if !GTK_CHECK_VERSION(2,6,0)
-#include <libgnomeui/libgnomeui.h>
-#else
-#define GNOME_DIALOG GTK_DIALOG
-#endif
-
 /* Local variables */
 static GtkWidget *new_pl_dialog;
 static GtkWidget *new_pl_entry;
@@ -91,7 +85,7 @@ static void remove_selected_row(void)
 {
   GtkTreeSelection *selection;
   GtkTreeIter iter;
-  
+
   selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(playlist_widgets.pltreeview));
   if (gtk_tree_selection_get_selected (selection, (GtkTreeModel **) &playlist_widgets.pltreestore, &iter)) {
     gtk_tree_store_remove(playlist_widgets.pltreestore, &iter);
@@ -105,7 +99,7 @@ static gboolean foreach_renumber(GtkTreeModel *model,
 {
   gchar *text;
   gchar **swap = (gchar **) data;
-  
+
   gtk_tree_model_get(model, iter, PLIST_PLID_COLUMN, &text, -1);
   /* g_print("Found playlist %s\n", text); */
   if (!strcmp(text, swap[0])) {
@@ -136,7 +130,6 @@ static void update_playlistid_in_store(guint32 old_plid, guint32 new_plid)
  * CALLBACK FUNCTIONS FOR GUI
  ***************************************************************************************/
 
-#if GTK_CHECK_VERSION(2,6,0)
 /* Deletes the dialog windows, passed as data */
 GCallback dispose_of_dialog_window(GtkButton * button, gpointer data)
 {
@@ -144,7 +137,6 @@ GCallback dispose_of_dialog_window(GtkButton * button, gpointer data)
 	gtk_widget_destroy(tmpwid);
 	return NULL;
 }
-#endif
 
 static GCallback create_new_playlist_ok_button (GtkButton *button,
 						gpointer data)
@@ -164,53 +156,38 @@ static GCallback create_new_playlist_ok_button (GtkButton *button,
 static GCallback playlist_new_response(gpointer data)
 {
   GtkWidget *label, *button;
-#if !GTK_CHECK_VERSION(2,6,0)  
-  new_pl_dialog = gnome_dialog_new(_("Create a new playlist"),
-				   GNOME_STOCK_BUTTON_CANCEL,
-				   GNOME_STOCK_BUTTON_OK,
-				   NULL);
-  gnome_dialog_button_connect_object(GNOME_DIALOG(new_pl_dialog),
-				     0,
-				     GTK_SIGNAL_FUNC(gtk_widget_destroy),
-				     GTK_OBJECT(new_pl_dialog));
-  gnome_dialog_button_connect(GNOME_DIALOG(new_pl_dialog),
-			      1,
-			      GTK_SIGNAL_FUNC(create_new_playlist_ok_button),
-			      NULL);
-#else
+
   new_pl_dialog=gtk_dialog_new_with_buttons(_("Create a new playlist"),
-		  NULL, 
-		  0, 
+		  NULL,
+		  0,
 		  NULL);
 
-  button = gtk_dialog_add_button(GTK_DIALOG(new_pl_dialog), 
-		  GTK_STOCK_CANCEL, 
+  button = gtk_dialog_add_button(GTK_DIALOG(new_pl_dialog),
+		  GTK_STOCK_CANCEL,
 		  0);
-  g_signal_connect(button, 
-		  "clicked", 
-		  GTK_SIGNAL_FUNC(dispose_of_dialog_window), 
+  g_signal_connect(button,
+		  "clicked",
+		  G_CALLBACK(dispose_of_dialog_window),
 		  GTK_OBJECT(new_pl_dialog));
 
-  button = gtk_dialog_add_button(GTK_DIALOG(new_pl_dialog), 
-		  GTK_STOCK_OK, 
+  button = gtk_dialog_add_button(GTK_DIALOG(new_pl_dialog),
+		  GTK_STOCK_OK,
 		  1);
-  g_signal_connect(button, 
-		  "clicked", 
-		  GTK_SIGNAL_FUNC(create_new_playlist_ok_button), 
+  g_signal_connect(button,
+		  "clicked",
+		  G_CALLBACK(create_new_playlist_ok_button),
 		  NULL);
-#endif
-	      
-  
+
   gtk_window_set_position (GTK_WINDOW(new_pl_dialog), GTK_WIN_POS_MOUSE);
 
   label = gtk_label_new(_("Choose a name for the new playlist:"));
-  gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(new_pl_dialog)->vbox), label, TRUE, TRUE, 0);
+  gtk_box_pack_start(GTK_BOX(GTK_DIALOG(new_pl_dialog)->vbox), label, TRUE, TRUE, 0);
   gtk_widget_show(label);
   new_pl_entry = gtk_entry_new();
-  gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(new_pl_dialog)->vbox), new_pl_entry, TRUE, TRUE, 0);
+  gtk_box_pack_start(GTK_BOX(GTK_DIALOG(new_pl_dialog)->vbox), new_pl_entry, TRUE, TRUE, 0);
   gtk_widget_show(new_pl_entry);
 
-  g_signal_connect(G_OBJECT (new_pl_dialog), 
+  g_signal_connect(G_OBJECT (new_pl_dialog),
 		   "delete_event",
 		   G_CALLBACK(gtk_widget_destroy),
 		   G_OBJECT (new_pl_dialog));
@@ -223,7 +200,7 @@ static GCallback playlist_new_response(gpointer data)
 static GCallback playlist_play_response(gpointer data)
 {
   guint32 plid;
-  
+
   if (jukebox_locked) {
     create_error_dialog(_("Jukebox busy"));
     return NULL;
@@ -261,55 +238,40 @@ static GCallback playlist_edit_response(gpointer data)
   GtkWidget *label, *button;
   gchar *text;
 
-#if !GTK_CHECK_VERSION(2,6,0)
-  edit_pl_dialog = gnome_dialog_new(_("Edit playlist"),
-				    GNOME_STOCK_BUTTON_CANCEL,
-				    GNOME_STOCK_BUTTON_OK,
-				    NULL);
-  gnome_dialog_button_connect_object(GNOME_DIALOG(edit_pl_dialog),
-				     0,
-				     GTK_SIGNAL_FUNC(gtk_widget_destroy),
-				     GTK_OBJECT(edit_pl_dialog));
-  gnome_dialog_button_connect(GNOME_DIALOG(edit_pl_dialog),
-			      1,
-			      GTK_SIGNAL_FUNC(edit_playlist_ok_button),
-			      NULL);
- #else
   edit_pl_dialog=gtk_dialog_new_with_buttons(_("Edit playlist"),
-		  NULL, 
-		  0, 
+		  NULL,
+		  0,
 		  NULL);
 
-  button = gtk_dialog_add_button(GTK_DIALOG(edit_pl_dialog), 
-		  GTK_STOCK_CANCEL, 
+  button = gtk_dialog_add_button(GTK_DIALOG(edit_pl_dialog),
+		  GTK_STOCK_CANCEL,
 		  0);
-  g_signal_connect(button, 
-		  "clicked", 
-		  GTK_SIGNAL_FUNC(dispose_of_dialog_window), 
+  g_signal_connect(button,
+		  "clicked",
+		  G_CALLBACK(dispose_of_dialog_window),
 		  GTK_OBJECT(edit_pl_dialog));
 
-  button = gtk_dialog_add_button(GTK_DIALOG(edit_pl_dialog), 
-		  GTK_STOCK_OK, 
+  button = gtk_dialog_add_button(GTK_DIALOG(edit_pl_dialog),
+		  GTK_STOCK_OK,
 		  1);
-  g_signal_connect(button, 
-		  "clicked", 
-		  GTK_SIGNAL_FUNC(edit_playlist_ok_button), 
+  g_signal_connect(button,
+		  "clicked",
+		  G_CALLBACK(edit_playlist_ok_button),
 		  NULL);
-#endif
- gtk_window_set_position (GTK_WINDOW(edit_pl_dialog), GTK_WIN_POS_MOUSE);
+  gtk_window_set_position (GTK_WINDOW(edit_pl_dialog), GTK_WIN_POS_MOUSE);
 
   label = gtk_label_new(_("Edit the name for this playlist:"));
-  gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(edit_pl_dialog)->vbox), label, TRUE, TRUE, 0);
+  gtk_box_pack_start(GTK_BOX(GTK_DIALOG(edit_pl_dialog)->vbox), label, TRUE, TRUE, 0);
   gtk_widget_show(label);
   edit_pl_entry = gtk_entry_new();
   // Get the old name of the playlist
   text = get_text_from_selection_column(PLIST_PLAYLISTNAME_COLUMN);
   if (text != NULL) {
-    gtk_entry_set_text(GTK_ENTRY(edit_pl_entry), 
+    gtk_entry_set_text(GTK_ENTRY(edit_pl_entry),
 		       text);
     g_free(text);
   }
-  gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(edit_pl_dialog)->vbox), edit_pl_entry, TRUE, TRUE, 0);
+  gtk_box_pack_start(GTK_BOX(GTK_DIALOG(edit_pl_dialog)->vbox), edit_pl_entry, TRUE, TRUE, 0);
   gtk_widget_show(edit_pl_entry);
   g_signal_connect_object(GTK_OBJECT (edit_pl_dialog),
 			  "delete_event",
@@ -448,7 +410,7 @@ static GCallback export_playlist_ok_button (GtkButton *button,
 static GCallback playlist_export_response(gpointer data)
 {
   guint plid;
-  
+
   if (jukebox_locked) {
     create_error_dialog(_("Jukebox busy"));
     return NULL;
@@ -461,76 +423,61 @@ static GCallback playlist_export_response(gpointer data)
     gchar *text;
 
     if (playlist != NULL) {
-#if !GTK_CHECK_VERSION(2,6,0)
-      export_pl_dialog = gnome_dialog_new(_("Export playlist"),
-					  GNOME_STOCK_BUTTON_CANCEL,
-					  GNOME_STOCK_BUTTON_OK,
-					  NULL);
-      gnome_dialog_button_connect_object(GNOME_DIALOG(export_pl_dialog),
-					 0,
-					 GTK_SIGNAL_FUNC(gtk_widget_destroy),
-					 GTK_OBJECT(export_pl_dialog));
-      gnome_dialog_button_connect(GNOME_DIALOG(export_pl_dialog),
-				  1,
-				  GTK_SIGNAL_FUNC(export_playlist_ok_button),
-				  playlist);
- #else
       GtkWidget * button;
       export_pl_dialog=gtk_dialog_new_with_buttons(_("Export playlist"),
-		  NULL, 
-		  0, 
+		  NULL,
+		  0,
 		  NULL);
 
-      button = gtk_dialog_add_button(GTK_DIALOG(export_pl_dialog), 
-		  GTK_STOCK_CANCEL, 
+      button = gtk_dialog_add_button(GTK_DIALOG(export_pl_dialog),
+		  GTK_STOCK_CANCEL,
 		  0);
-      g_signal_connect(button, 
-		  "clicked", 
-		  GTK_SIGNAL_FUNC(dispose_of_dialog_window), 
+      g_signal_connect(button,
+		  "clicked",
+		  G_CALLBACK(dispose_of_dialog_window),
 		  GTK_OBJECT(export_pl_dialog));
 
-      button = gtk_dialog_add_button(GTK_DIALOG(export_pl_dialog), 
-		  GTK_STOCK_OK, 
+      button = gtk_dialog_add_button(GTK_DIALOG(export_pl_dialog),
+		  GTK_STOCK_OK,
 		  1);
-      g_signal_connect(button, 
-		  "clicked", 
-		  GTK_SIGNAL_FUNC(export_playlist_ok_button), 
+      g_signal_connect(button,
+		  "clicked",
+		  G_CALLBACK(export_playlist_ok_button),
 		  playlist);
-#endif
       gtk_window_set_position (GTK_WINDOW(export_pl_dialog), GTK_WIN_POS_MOUSE);
-      
+
       label = gtk_label_new(_("Export playlist to this file:"));
-      gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(export_pl_dialog)->vbox), label, TRUE, TRUE, 0);
+      gtk_box_pack_start(GTK_BOX(GTK_DIALOG(export_pl_dialog)->vbox), label, TRUE, TRUE, 0);
       gtk_widget_show(label);
       export_pl_entry = gtk_entry_new();
       // Get the old name of the playlist
       text = get_text_from_selection_column(PLIST_PLAYLISTNAME_COLUMN);
       if (text != NULL) {
 	text = stringcat(text, ".txt");
-	gtk_entry_set_text(GTK_ENTRY(export_pl_entry), 
+	gtk_entry_set_text(GTK_ENTRY(export_pl_entry),
 			   text);
 	g_free(text);
       } else {
-	gtk_entry_set_text(GTK_ENTRY(export_pl_entry), 
+	gtk_entry_set_text(GTK_ENTRY(export_pl_entry),
 			   _("Unnamed playlist.txt"));
       }
-      gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(export_pl_dialog)->vbox), export_pl_entry, TRUE, TRUE, 0);
+      gtk_box_pack_start(GTK_BOX(GTK_DIALOG(export_pl_dialog)->vbox), export_pl_entry, TRUE, TRUE, 0);
       gtk_widget_show(export_pl_entry);
 
       label = gtk_label_new(_("Format the playlist according to this string:"));
-      gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(export_pl_dialog)->vbox), label, TRUE, TRUE, 0);
+      gtk_box_pack_start(GTK_BOX(GTK_DIALOG(export_pl_dialog)->vbox), label, TRUE, TRUE, 0);
       gtk_widget_show(label);
 
       export_pl_format_entry = gtk_entry_new();
       text = get_prefs_filenameformat();
       gtk_entry_set_text(GTK_ENTRY(export_pl_format_entry), text);
       g_free(text);
-      gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(export_pl_dialog)->vbox), export_pl_format_entry, TRUE, TRUE, 0);
+      gtk_box_pack_start(GTK_BOX(GTK_DIALOG(export_pl_dialog)->vbox), export_pl_format_entry, TRUE, TRUE, 0);
       gtk_widget_show(export_pl_format_entry);
 
       /* Don't translate the magic %-things! */
       label = gtk_label_new(_("%a = Artist, %t = Title, %b = Album, %g = Genre, %n = Track number, %y = Year"));
-      gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(export_pl_dialog)->vbox), label, TRUE, TRUE, 0);
+      gtk_box_pack_start(GTK_BOX(GTK_DIALOG(export_pl_dialog)->vbox), label, TRUE, TRUE, 0);
       gtk_widget_show(label);
 
       m3ulist = gtk_check_button_new_with_label(_("Create an M3U playlist (assuming the format filter sets " \
@@ -540,7 +487,7 @@ static GCallback playlist_export_response(gpointer data)
 			      G_CALLBACK(toggle_m3ulist),
 			      NULL,
 			      0);
-      gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(export_pl_dialog)->vbox), m3ulist, TRUE, TRUE, 0);
+      gtk_box_pack_start(GTK_BOX(GTK_DIALOG(export_pl_dialog)->vbox), m3ulist, TRUE, TRUE, 0);
       gtk_widget_show(m3ulist);
 
       plslist = gtk_check_button_new_with_label(_("Create an PLS playlist (assuming the format filter sets " \
@@ -550,7 +497,7 @@ static GCallback playlist_export_response(gpointer data)
 			      G_CALLBACK(toggle_plslist),
 			      NULL,
 			      0);
-      gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(export_pl_dialog)->vbox), plslist, TRUE, TRUE, 0);
+      gtk_box_pack_start(GTK_BOX(GTK_DIALOG(export_pl_dialog)->vbox), plslist, TRUE, TRUE, 0);
       gtk_widget_show(plslist);
 
       g_signal_connect_object(GTK_OBJECT (export_pl_dialog),
@@ -652,35 +599,33 @@ static GCallback mouseevent (GtkWidget      *clist,
 
 static GtkWidget *create_option_menu(void)
 {
-  GtkWidget *option_menu;
-  GSList *group = NULL;
-  GtkWidget *menu;
-  GtkWidget *menu_item;
+  GtkWidget *combo;
   GList *tmplist = g_list_first(jukebox_playlist);
 
   /* Create the option menu */
-  option_menu = gtk_option_menu_new();
-  menu = gtk_menu_new();
-  menu_item = gtk_radio_menu_item_new_with_label(group, "(None)");
-  group = gtk_radio_menu_item_get_group(GTK_RADIO_MENU_ITEM(menu_item));
-  gtk_menu_shell_append(GTK_MENU_SHELL(menu), menu_item);
-  /* Check the first item */
-  gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(menu_item), TRUE);
-  gtk_widget_show(menu_item);
+#if GTK_CHECK_VERSION(2,24,0)
+  // Use the new combo box type in 2.24 and later
+  combo = gtk_combo_box_text_new();
+  gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(combo), "(None)");
+#else
+  combo = gtk_combo_box_new_text();
+  gtk_combo_box_append_text(GTK_COMBO_BOX(combo), "(None)");
+#endif
 
   /* Add a row to the menu */
   while (tmplist) {
-    menu_item = gtk_radio_menu_item_new_with_label(group, tmplist->data);
+#if GTK_CHECK_VERSION(2,24,0)
+    gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(combo), tmplist->data);
+#else
+    gtk_combo_box_append_text(GTK_COMBO_BOX(combo), tmplist->data);
+#endif
     tmplist = tmplist->next;
-    group = gtk_radio_menu_item_get_group(GTK_RADIO_MENU_ITEM (menu_item));
-    gtk_menu_shell_append(GTK_MENU_SHELL(menu), menu_item);
-    gtk_widget_show(menu_item);
     tmplist = tmplist->next;
   }
-  gtk_option_menu_set_menu (GTK_OPTION_MENU (option_menu), menu);
-  gtk_option_menu_set_history (GTK_OPTION_MENU (option_menu), 0);
 
-  return option_menu;
+  gtk_combo_box_set_active(GTK_COMBO_BOX(combo), 0);
+
+  return combo;
 }
 
 /* Pre-declare this function */
@@ -695,7 +640,7 @@ static GCallback toggle_and(gpointer a, gpointer b)
   gtk_toggle_button_set_active(tbutton, TRUE);
   gtk_widget_set_sensitive(GTK_WIDGET(tbutton), FALSE);
   /* If this was not previously selected, it's time to create a new one */
-  add_pl_selection(GTK_BOX(GNOME_DIALOG(select_playlist_dialog)->vbox), next);
+  add_pl_selection(GTK_BOX(GTK_DIALOG(select_playlist_dialog)->vbox), next);
   return NULL;
 }
 
@@ -715,7 +660,7 @@ static void add_pl_selection(GtkBox *box, guint number)
   gtk_widget_show(option_menu);
   /* and .. */
   and = gtk_check_button_new_with_label(_("and"));
-  g_signal_connect(GTK_OBJECT(and), 
+  g_signal_connect(GTK_OBJECT(and),
 		   "clicked",
 		   G_CALLBACK(toggle_and),
 		   GUINT_TO_POINTER(number));
@@ -725,7 +670,7 @@ static void add_pl_selection(GtkBox *box, guint number)
   gtk_widget_show(hbox);
 }
 
-static void playlist_selection_dialog(gchar *title, gchar *prompt, GtkSignalFunc ok_signal)
+static void playlist_selection_dialog(gchar *title, gchar *prompt, GCallback ok_signal)
 {
   GtkWidget *label, *button;
 
@@ -734,41 +679,26 @@ static void playlist_selection_dialog(gchar *title, gchar *prompt, GtkSignalFunc
     g_list_free(selected_target_playlists);
     selected_target_playlists = NULL;
   }
-#if !GTK_CHECK_VERSION(2,6,0)
-  select_playlist_dialog = gnome_dialog_new(title,
-					    GNOME_STOCK_BUTTON_CANCEL,
-					    GNOME_STOCK_BUTTON_OK,
-					    NULL);
-  gnome_dialog_button_connect_object(GNOME_DIALOG(select_playlist_dialog),
-				     0,
-				     G_CALLBACK(gtk_widget_destroy),
-				     GTK_OBJECT(select_playlist_dialog));
-  gnome_dialog_button_connect(GNOME_DIALOG(select_playlist_dialog),
-			      1,
-			      G_CALLBACK(ok_signal),
-			      NULL);
-#else
   select_playlist_dialog=gtk_dialog_new_with_buttons(title,
-		  NULL, 
-		  0, 
+		  NULL,
+		  0,
 		  NULL);
 
-  button = gtk_dialog_add_button(GTK_DIALOG(select_playlist_dialog), 
-		  GTK_STOCK_CANCEL, 
+  button = gtk_dialog_add_button(GTK_DIALOG(select_playlist_dialog),
+		  GTK_STOCK_CANCEL,
 		  0);
-  g_signal_connect(button, 
-		  "clicked", 
-		  GTK_SIGNAL_FUNC(dispose_of_dialog_window), 
+  g_signal_connect(button,
+		  "clicked",
+		  G_CALLBACK(dispose_of_dialog_window),
 		  GTK_OBJECT(select_playlist_dialog));
 
-  button = gtk_dialog_add_button(GTK_DIALOG(select_playlist_dialog), 
-		  GTK_STOCK_OK, 
+  button = gtk_dialog_add_button(GTK_DIALOG(select_playlist_dialog),
+		  GTK_STOCK_OK,
 		  1);
-  g_signal_connect(button, 
-		  "clicked", 
-		  GTK_SIGNAL_FUNC(ok_signal), 
+  g_signal_connect(button,
+		  "clicked",
+		  G_CALLBACK(ok_signal),
 		  NULL);
-#endif
   gtk_window_set_position (GTK_WINDOW(select_playlist_dialog), GTK_WIN_POS_MOUSE);
   g_signal_connect_object(GTK_OBJECT (select_playlist_dialog),
 			  "delete_event",
@@ -778,9 +708,9 @@ static void playlist_selection_dialog(gchar *title, gchar *prompt, GtkSignalFunc
   /* Add a label and the option menu */
   label = gtk_label_new(prompt);
   gtk_widget_show(label);
-  gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(select_playlist_dialog)->vbox), label, TRUE, TRUE, 0);
+  gtk_box_pack_start(GTK_BOX(GTK_DIALOG(select_playlist_dialog)->vbox), label, TRUE, TRUE, 0);
   /* Initially add one selector */
-  add_pl_selection(GTK_BOX(GNOME_DIALOG(select_playlist_dialog)->vbox), 0);
+  add_pl_selection(GTK_BOX(GTK_DIALOG(select_playlist_dialog)->vbox), 0);
   gtk_widget_show(select_playlist_dialog);
 }
 
@@ -792,7 +722,9 @@ static GList *get_selected_playlists(void)
 
   templist = g_list_first(selected_target_playlists);
   while (templist != NULL) {
-    guint selection = gtk_option_menu_get_history(GTK_OPTION_MENU(templist->data));
+    guint selection;
+
+    selection = gtk_combo_box_get_active(GTK_COMBO_BOX(templist->data));
     if (selection != 0) {
       /* Find out playlist ID of this entry */
       GList *tmp = g_list_nth(jukebox_playlist, (selection-1)*2+1);
@@ -860,16 +792,16 @@ void transfer_from_hd_dialog (GtkButton *inbutton,
     transfer_from_hd_to_jukebox(NULL);
     return;
   }
-  playlist_selection_dialog(_("Transfer to jukebox library"), 
-			    _("Add tracks to playlist(s):"), 
-			    GTK_SIGNAL_FUNC(transfer_from_hd_ok_button));
+  playlist_selection_dialog(_("Transfer to jukebox library"),
+			    _("Add tracks to playlist(s):"),
+			    G_CALLBACK(transfer_from_hd_ok_button));
 }
 
 void jbmenu_add_playlist_response(gpointer data)
 {
-  playlist_selection_dialog(_("Add to playlist"), 
-			    _("Add tracks to playlist(s):"), 
-			    GTK_SIGNAL_FUNC(add_to_playlist_ok_button));
+  playlist_selection_dialog(_("Add to playlist"),
+			    _("Add tracks to playlist(s):"),
+			    G_CALLBACK(add_to_playlist_ok_button));
 }
 
 static GtkWidget *create_treeview(GtkTreeStore *treestore)
@@ -881,7 +813,7 @@ static GtkWidget *create_treeview(GtkTreeStore *treestore)
 
   treeview = gtk_tree_view_new_with_model(GTK_TREE_MODEL(treestore));
   gtk_tree_view_set_rules_hint(GTK_TREE_VIEW(treeview), TRUE);
-  
+
   textrenderer = gtk_cell_renderer_text_new ();
 
   view = gtk_tree_view_column_new_with_attributes (_("Playlist"),
@@ -974,16 +906,16 @@ void create_playlist_widgets(GtkWidget *box)
 {
   GtkWidget *scrolled_window, *pltreeview, *playlistpopupmenu,
     *blankpopupmenu, *nodepopupmenu, *popupmenu_item;
-  
+
   selected_target_playlists = NULL;
 
   /* The popup menu for the playlists */
   blankpopupmenu = gtk_menu_new();
   popupmenu_item  = gtk_menu_item_new_with_label(_("New playlist"));
   gtk_menu_shell_append (GTK_MENU_SHELL(blankpopupmenu), popupmenu_item);
-  g_signal_connect_object(GTK_OBJECT (popupmenu_item), 
+  g_signal_connect_object(GTK_OBJECT (popupmenu_item),
 			  "activate",
-			  G_CALLBACK(playlist_new_response), 
+			  G_CALLBACK(playlist_new_response),
 			  NULL,
 			  0);
   gtk_widget_show (popupmenu_item);
@@ -991,49 +923,49 @@ void create_playlist_widgets(GtkWidget *box)
   playlistpopupmenu = gtk_menu_new();
   popupmenu_item  = gtk_menu_item_new_with_label(_("New playlist"));
   gtk_menu_shell_append(GTK_MENU_SHELL(playlistpopupmenu), popupmenu_item);
-  g_signal_connect_object(GTK_OBJECT (popupmenu_item), 
+  g_signal_connect_object(GTK_OBJECT (popupmenu_item),
 			  "activate",
-			  G_CALLBACK(playlist_new_response), 
+			  G_CALLBACK(playlist_new_response),
 			  NULL,
 			  0);
   gtk_widget_show (popupmenu_item);
   popupmenu_item  = gtk_menu_item_new_with_label(_("Shuffle playlist"));
   gtk_menu_shell_append(GTK_MENU_SHELL(playlistpopupmenu), popupmenu_item);
-  g_signal_connect_object(GTK_OBJECT (popupmenu_item), 
+  g_signal_connect_object(GTK_OBJECT (popupmenu_item),
 			  "activate",
-			  G_CALLBACK(playlist_shuffle_response), 
+			  G_CALLBACK(playlist_shuffle_response),
 			  NULL,
 			  0);
   gtk_widget_show (popupmenu_item);
   popupmenu_item  = gtk_menu_item_new_with_label(_("Play playlist"));
   gtk_menu_shell_append(GTK_MENU_SHELL(playlistpopupmenu), popupmenu_item);
-  g_signal_connect_object(GTK_OBJECT (popupmenu_item), 
+  g_signal_connect_object(GTK_OBJECT (popupmenu_item),
 			  "activate",
-			  G_CALLBACK(playlist_play_response), 
+			  G_CALLBACK(playlist_play_response),
 			  NULL,
 			  0);
   gtk_widget_show (popupmenu_item);
   popupmenu_item  = gtk_menu_item_new_with_label(_("Edit playlist"));
   gtk_menu_shell_append(GTK_MENU_SHELL(playlistpopupmenu), popupmenu_item);
-  g_signal_connect_object(GTK_OBJECT (popupmenu_item), 
+  g_signal_connect_object(GTK_OBJECT (popupmenu_item),
 			  "activate",
-			  G_CALLBACK(playlist_edit_response), 
+			  G_CALLBACK(playlist_edit_response),
 			  NULL,
 			  0);
   gtk_widget_show (popupmenu_item);
   popupmenu_item  = gtk_menu_item_new_with_label(_("Export playlist"));
   gtk_menu_shell_append(GTK_MENU_SHELL(playlistpopupmenu), popupmenu_item);
-  g_signal_connect_object(GTK_OBJECT (popupmenu_item), 
+  g_signal_connect_object(GTK_OBJECT (popupmenu_item),
 			  "activate",
-			  G_CALLBACK(playlist_export_response), 
+			  G_CALLBACK(playlist_export_response),
 			  NULL,
 			  0);
   gtk_widget_show (popupmenu_item);
   popupmenu_item  = gtk_menu_item_new_with_label(_("Delete playlist"));
   gtk_menu_shell_append(GTK_MENU_SHELL(playlistpopupmenu), popupmenu_item);
-  g_signal_connect_object(GTK_OBJECT (popupmenu_item), 
+  g_signal_connect_object(GTK_OBJECT (popupmenu_item),
 			  "activate",
-			  G_CALLBACK(playlist_delete_response), 
+			  G_CALLBACK(playlist_delete_response),
 			  NULL,
 			  0);
   gtk_widget_show (popupmenu_item);
@@ -1041,17 +973,17 @@ void create_playlist_widgets(GtkWidget *box)
   nodepopupmenu = gtk_menu_new ();
   popupmenu_item  = gtk_menu_item_new_with_label(_("New playlist"));
   gtk_menu_shell_append(GTK_MENU_SHELL(nodepopupmenu), popupmenu_item);
-  g_signal_connect_object(GTK_OBJECT(popupmenu_item), 
+  g_signal_connect_object(GTK_OBJECT(popupmenu_item),
 			  "activate",
-			  G_CALLBACK(playlist_new_response), 
+			  G_CALLBACK(playlist_new_response),
 			  NULL,
 			  0);
   gtk_widget_show (popupmenu_item);
   popupmenu_item  = gtk_menu_item_new_with_label(_("Delete track from playlist"));
   gtk_menu_shell_append(GTK_MENU_SHELL(nodepopupmenu), popupmenu_item);
-  g_signal_connect_object(GTK_OBJECT (popupmenu_item), 
+  g_signal_connect_object(GTK_OBJECT (popupmenu_item),
 			  "activate",
-			  G_CALLBACK(node_delete_response), 
+			  G_CALLBACK(node_delete_response),
 			  NULL,
 			  0);
   gtk_widget_show (popupmenu_item);
