@@ -21,9 +21,9 @@ Boston, MA 02111-1307, USA.
 #include "util.h"
 #include "filesystem.h"
 
-static GtkWidget *id3override = NULL;
-static GtkWidget *id3remove = NULL;
-static GtkWidget *useid3 = NULL;
+static GtkWidget *tagoverride = NULL;
+static GtkWidget *tagremove = NULL;
+static GtkWidget *usetag = NULL;
 static GtkWidget *useid3_unicode = NULL;
 static GtkWidget *display_dotdirs = NULL;
 #ifndef G_OS_WIN32
@@ -54,8 +54,8 @@ static void read_prefs_file(void)
   gchar *name;
 
   /* These shall be TRUE by default */
-  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(id3remove), TRUE);
-  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(useid3), TRUE);
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(tagremove), TRUE);
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(usetag), TRUE);
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(useid3_unicode), TRUE);
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(ask_playlist), TRUE);
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(detect_metadata), TRUE);
@@ -99,21 +99,22 @@ static void read_prefs_file(void)
 	  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(display_dotdirs), TRUE);
 	else
 	  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(display_dotdirs), FALSE);
-      } else if (!strcmp(name, "ID3_REMOVE")) {
+      } else if (!strcmp(name, "ID3_REMOVE") || !strcmp(name, "TAG_REMOVE")) {
 	if (g_scanner_cur_value(scanner).v_int)
-	  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(id3remove), TRUE);
+	  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(tagremove), TRUE);
 	else
-	  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(id3remove), FALSE);
-      } else if (!strcmp(name, "ID3_OVERRIDE")) {
+	  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(tagremove), FALSE);
+      } else if (!strcmp(name, "ID3_OVERRIDE") || !strcmp(name, "TAG_OVERRIDE")) {
 	if (g_scanner_cur_value(scanner).v_int)
-	  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(id3override), TRUE);
+	  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(tagoverride), TRUE);
 	else
-	  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(id3override), FALSE);
-      } else if (!strcmp(name, "USE_ID3V1") || !strcmp(name, "USE_ID3V2") || !strcmp(name, "USE_ID3")) {
+	  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(tagoverride), FALSE);
+      } else if (!strcmp(name, "USE_ID3V1") || !strcmp(name, "USE_ID3V2") || 
+		 !strcmp(name, "USE_ID3") || !strcmp(name, "USE_TAG")) {
 	if (g_scanner_cur_value(scanner).v_int)
-	  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(useid3), TRUE);
+	  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(usetag), TRUE);
 	else
-	  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(useid3), FALSE);
+	  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(usetag), FALSE);
       } else if (!strcmp(name, "USE_ID3_UNICODE")) {
 	if (g_scanner_cur_value(scanner).v_int)
 	  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(useid3_unicode), TRUE);
@@ -205,20 +206,20 @@ void write_prefs_file(void)
   else
     prefs = stringcat(prefs, "0");
   prefs = stringcat(prefs, "\n");
-  prefs = stringcat(prefs, "ID3_REMOVE=");
-  if (get_prefs_id3remove())
+  prefs = stringcat(prefs, "TAG_REMOVE=");
+  if (get_prefs_tagremove())
     prefs = stringcat(prefs, "1");
   else
     prefs = stringcat(prefs, "0");
   prefs = stringcat(prefs, "\n");
-  prefs = stringcat(prefs, "ID3_OVERRIDE=");
-  if (get_prefs_id3override())
+  prefs = stringcat(prefs, "TAG_OVERRIDE=");
+  if (get_prefs_tagoverride())
     prefs = stringcat(prefs, "1");
   else
     prefs = stringcat(prefs, "0");
   prefs = stringcat(prefs, "\n");
-  prefs = stringcat(prefs, "USE_ID3=");
-  if (get_prefs_useid3())
+  prefs = stringcat(prefs, "USE_TAG=");
+  if (get_prefs_usetag())
     prefs = stringcat(prefs, "1");
   else
     prefs = stringcat(prefs, "0");
@@ -303,28 +304,28 @@ gboolean get_prefs_use_origname(void)
     return gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(use_origname));
 }
 
-gboolean get_prefs_id3override(void)
+gboolean get_prefs_tagoverride(void)
 {
-  if (id3override == NULL)
+  if (tagoverride == NULL)
     return FALSE;
   else
-    return gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(id3override));
+    return gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(tagoverride));
 }
 
-gboolean get_prefs_id3remove(void)
+gboolean get_prefs_tagremove(void)
 {
-  if (id3remove == NULL)
+  if (tagremove == NULL)
     return FALSE;
   else
-    return gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(id3remove));
+    return gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(tagremove));
 }
 
-gboolean get_prefs_useid3(void)
+gboolean get_prefs_usetag(void)
 {
-  if (useid3 == NULL)
+  if (usetag == NULL)
     return FALSE;
   else
-    return gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(useid3));
+    return gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(usetag));
 }
 
 gboolean get_prefs_useid3_unicode(void)
@@ -423,7 +424,7 @@ gchar *get_prefs_filenameformat(void)
   static gchar defaultformat[] = "%a - %t";
   G_CONST_RETURN gchar *returnformat;
   
-  if (id3remove == NULL)
+  if (tagremove == NULL)
     returnformat = defaultformat;
   returnformat = gtk_entry_get_text(GTK_ENTRY(filenameformat));
   if (!strlen(returnformat))
@@ -495,14 +496,14 @@ void create_prefs_widgets(GtkWidget *box)
   gtk_box_pack_start(GTK_BOX(vbox), frame, FALSE, FALSE, 0);
 
   /* Checkbutton preferences */
-  id3override = 
+  tagoverride = 
     gtk_check_button_new_with_label(_("Metadata from the jukebox overrides " \
-				      "present ID3 tags on transfered files"));
-  id3remove = 
-    gtk_check_button_new_with_label(_("Remove all ID3 tags from files " \
+				      "present tags on transfered files"));
+  tagremove = 
+    gtk_check_button_new_with_label(_("Remove all metadata tags from files "	\
 				      "transferred to jukebox"));
-  useid3 =
-    gtk_check_button_new_with_label(_("Write ID3v1/v2 tag to files transferred to " \
+  usetag =
+    gtk_check_button_new_with_label(_("Write tags to files transferred to " \
 				      "harddisk"));
   useid3_unicode =
     gtk_check_button_new_with_label(_("Force use of Unicode charset for ID3 tags"));
@@ -534,9 +535,9 @@ void create_prefs_widgets(GtkWidget *box)
     gtk_check_button_new_with_label(_("On startup, return to the place in the filesystem where you were last time"));
   turbo_mode =
     gtk_check_button_new_with_label(_("Enable turbo mode - uncheck this if you have problems"));
-  gtk_box_pack_start(GTK_BOX(vbox), id3override, FALSE, FALSE, 0);
-  gtk_box_pack_start(GTK_BOX(vbox), id3remove, FALSE, FALSE, 0);
-  gtk_box_pack_start(GTK_BOX(vbox), useid3, FALSE, FALSE, 0);
+  gtk_box_pack_start(GTK_BOX(vbox), tagoverride, FALSE, FALSE, 0);
+  gtk_box_pack_start(GTK_BOX(vbox), tagremove, FALSE, FALSE, 0);
+  gtk_box_pack_start(GTK_BOX(vbox), usetag, FALSE, FALSE, 0);
   gtk_box_pack_start(GTK_BOX(vbox), useid3_unicode, FALSE, FALSE, 0);
   gtk_box_pack_start(GTK_BOX(vbox), display_dotdirs, FALSE, FALSE, 0);
   gtk_box_pack_start(GTK_BOX(vbox), ask_playlist, FALSE, FALSE, 0);
@@ -550,9 +551,9 @@ void create_prefs_widgets(GtkWidget *box)
   gtk_box_pack_start(GTK_BOX(vbox), set_time, FALSE, FALSE, 0);
   gtk_box_pack_start(GTK_BOX(vbox), remember_dir, FALSE, FALSE, 0);
   gtk_box_pack_start(GTK_BOX(vbox), turbo_mode, FALSE, FALSE, 0);
-  gtk_widget_show(id3override);
-  gtk_widget_show(id3remove);
-  gtk_widget_show(useid3);
+  gtk_widget_show(tagoverride);
+  gtk_widget_show(tagremove);
+  gtk_widget_show(usetag);
   gtk_widget_show(useid3_unicode);
   gtk_widget_show(display_dotdirs);
   gtk_widget_show(ask_playlist);
