@@ -25,9 +25,9 @@ Boston, MA 02111-1307, USA.
 
 /* Exported functions */
 void write_prefs_file(void);
-gboolean get_prefs_id3override(void);
-gboolean get_prefs_id3remove(void);
-gboolean get_prefs_useid3(void);
+gboolean get_prefs_tagoverride(void);
+gboolean get_prefs_tagremove(void);
+gboolean get_prefs_usetag(void);
 gboolean get_prefs_useid3_unicode(void);
 gboolean get_prefs_display_dotdirs(void);
 gboolean get_prefs_ask_playlist(void);
