@@ -62,6 +62,10 @@ get_tag_for_file (metadata_t *meta)
   g_free(tmppath);
   
   tag = taglib_file_tag(file);
+  if (tag == NULL) {
+    g_print("tag was NULL in file %s", tmppath);
+    return;
+  }
   properties = taglib_file_audioproperties(file);
   
   gchar* artist = taglib_tag_artist(tag);
@@ -105,7 +109,11 @@ set_tag_for_file (metadata_t *meta, gboolean override)
   // If taglib >= 1.5
   // taglib_id3v2_set_default_text_encoding(TagLib_ID3v2_UTF16);
 
-  tag = taglib_file_tag(file);  
+  tag = taglib_file_tag(file);
+  if (tag == NULL) {
+    g_print("tag was NULL in file %s", tmppath);
+    return;
+  }
   
   if (meta->artist != NULL &&
       strcmp(meta->artist, "<Unknown>")) {
