@@ -1,6 +1,6 @@
 /* util.c
    General utility functions, eg for string formatting
-   Copyright (C) 2001 Linus Walleij
+   Copyright (C) 2001-2011 Linus Walleij
 
 This file is part of the GNOMAD package.
 
@@ -12,14 +12,11 @@ any later version.
 You should have received a copy of the GNU General Public License
 along with GNOMAD; see the file COPYING.  If not, write to
 the Free Software Foundation, 59 Temple Place - Suite 330,
-Boston, MA 02111-1307, USA. 
+Boston, MA 02111-1307, USA.
 
 */
 
 #include "common.h"
-#if !GTK_CHECK_VERSION(2,4,0)
-#include <libgnomeui/libgnomeui.h>
-#endif
 
 extern GtkWidget *main_window;
 
@@ -31,7 +28,7 @@ gint vectorlength(gchar **vector)
 
   if (!tmp)
     return 0;
-  
+
   while (*tmp)
     {
       size ++;
@@ -43,7 +40,7 @@ gint vectorlength(gchar **vector)
 /* Concatenate two dynamic strings */
 gchar *stringcat(gchar *org, gchar *add)
 {
-  /* This can be improved under GTK+ 2.0 
+  /* This can be improved under GTK+ 2.0
    * new GLib functions -> 2.0 */
   gchar *tmpstring;
 
@@ -87,7 +84,7 @@ gchar *replacestring(gchar *string, gchar *find, gchar *replace)
 
   if (!string || !find || !replace)
     return string;
-  
+
   tmp2 = g_strsplit(string, find, 0);
 
   /* This is the case when the replacement is in the
@@ -129,7 +126,7 @@ guint32 string_to_guint32(gchar *string)
 
   if (!string)
     return 0;
-  
+
   return (guint32) strtoul(string, &dummy, 10);
 }
 
@@ -179,15 +176,15 @@ guint32 mmss_to_seconds(gchar *mmss)
 gboolean is_a_number(gchar *string)
 {
   gchar *tmp;
-  
+
   if (string == NULL)
     return FALSE;
   tmp = string;
   while (*tmp)
     {
       /* See if it is not a number, skip spaces */
-      if ((*tmp < '0' || 
-	   *tmp > '9') && 
+      if ((*tmp < '0' ||
+	   *tmp > '9') &&
 	  *tmp != ' ' &&
 	  *tmp != '.')
 	return FALSE;
@@ -209,7 +206,6 @@ void create_error_dialog(gchar *errorstring)
 {
   GtkWidget *dialog;
 
-#if GTK_CHECK_VERSION(2,4,0)
   dialog = gtk_message_dialog_new (GTK_WINDOW(main_window),
 				   GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
 				   GTK_MESSAGE_ERROR,
@@ -220,19 +216,12 @@ void create_error_dialog(gchar *errorstring)
 			  G_CALLBACK(gtk_widget_destroy),
 			  NULL,
 			  0);
-  g_signal_connect_object(GTK_OBJECT(dialog), 
+  g_signal_connect_object(GTK_OBJECT(dialog),
 			  "response",
-			  G_CALLBACK(gtk_widget_destroy), 
+			  G_CALLBACK(gtk_widget_destroy),
 			  NULL,
 			  0);
   gtk_widget_show(dialog);
-#else
-  dialog = gnome_message_box_new (errorstring,
-				  GNOME_MESSAGE_BOX_ERROR,
-				  GNOME_STOCK_BUTTON_OK,
-				  NULL);
-  gtk_widget_show(dialog);
-#endif
 }
 
 gboolean request_confirmation_dialog(gchar *confirmstring)
@@ -241,7 +230,6 @@ gboolean request_confirmation_dialog(gchar *confirmstring)
   gint i;
   gboolean retval = FALSE;
 
-#if GTK_CHECK_VERSION(2,4,0)
   dialog = gtk_message_dialog_new (GTK_WINDOW(main_window),
 				   GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
 				   GTK_MESSAGE_QUESTION,
@@ -252,26 +240,7 @@ gboolean request_confirmation_dialog(gchar *confirmstring)
   if (i == GTK_RESPONSE_YES) {
     retval = TRUE;
   }
-#else
-  /*
-    I can't seem to get GNOMEUI to do this properly, so I'm leaving it
-    out for clients that do not have a sufficiently new GTK.
 
-    g_print("Awaiting confirmation (GNOMEUI): %s...\n", confirmstring);
-    dialog = gnome_message_box_new (confirmstring,
-				  GNOME_MESSAGE_BOX_QUESTION,
-				  GNOME_STOCK_BUTTON_YES,
-				  GNOME_STOCK_BUTTON_CANCEL,
-				  NULL);
-    gtk_widget_show(dialog);
-    i = gnome_dialog_run_and_close(GNOME_DIALOG(dialog));
-  
-    if (i == 0) {
-      retval = TRUE;
-    }
-  */
-  retval = TRUE;
-#endif
   return retval;
 }
 
@@ -282,7 +251,7 @@ void hexdump(unsigned char *data, guint len)
   for (i=0; i<len; i++) {
     if (i % 16 == 0 && i != 0) {
       g_print("  ");
-      
+
       for (j = i-16; j < i; j++) {
 	gchar ch = data[j];
 	g_print("%c", ( ch >= 0x20 && ch <= 0x7e ) ? ch : '.');
