@@ -1,6 +1,6 @@
 /* wmaread.c
    WMA interface
-   Copyright (C) 2004 Linus Walleij
+   Copyright (C) 2004-2011 Linus Walleij
 
 This file is part of the GNOMAD package.
 
@@ -12,7 +12,7 @@ any later version.
 You should have received a copy of the GNU General Public License
 along with GNOMAD; see the file COPYING.  If not, write to
 the Free Software Foundation, 59 Temple Place - Suite 330,
-Boston, MA 02111-1307, USA. 
+Boston, MA 02111-1307, USA.
 
 Much of the code in this file was derived from the getid3() code,
 written in PHP. The C implementation here is however made from
@@ -28,10 +28,8 @@ scratch.
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
-#if GLIB_CHECK_VERSION(2,6,0)
-#   include <glib.h>
-#   include <glib/gstdio.h>
-#endif
+#include <glib.h>
+#include <glib/gstdio.h>
 
 static gboolean
 guid_compare(guchar *guid1, guchar *guid2)
@@ -279,11 +277,7 @@ get_tag_for_wmafile (metadata_t *meta)
   gint n;
 
   // g_print("Getting WMA tag info for %s...\n", meta->path);
-#if !GLIB_CHECK_VERSION(2,6,0)
-  fd = (gint) open(tmppath, READONLY_FLAGS, 0);
-#else
   fd = (gint) g_open(tmppath, READONLY_FLAGS, 0);
-#endif
   if (fd < 0) {
     g_free(tmppath);
     return;
@@ -381,7 +375,7 @@ get_tag_for_wmafile (metadata_t *meta)
     //meta->album = getAlbum(tag);
     //meta->genre = getGenre(tag);
     //meta->year = string_to_guint32(getYear(tag));
-    
+
     /* If there is a songlength tag it will take
      * precedence over any length calculated from
      * the bitrate and filesize */
