@@ -1,6 +1,6 @@
 /* xfer.c
    Transfer window widgets and callbacks
-   Copyright (C) 2001 Linus Walleij
+   Copyright (C) 2001-2011 Linus Walleij
 
 This file is part of the GNOMAD package.
 
@@ -12,7 +12,7 @@ any later version.
 You should have received a copy of the GNU General Public License
 along with GNOMAD; see the file COPYING.  If not, write to
 the Free Software Foundation, 59 Temple Place - Suite 330,
-Boston, MA 02111-1307, USA. 
+Boston, MA 02111-1307, USA.
 
 */
 
@@ -28,12 +28,6 @@ Boston, MA 02111-1307, USA.
 #include "player.h"
 #include "xfer.h"
 
-#if !GTK_CHECK_VERSION(2,6,0)
-#include <libgnomeui/libgnomeui.h>
-#else
-#define GNOME_DIALOG GTK_DIALOG
-#endif
-
 /* Local variables */
 static GtkWidget *new_folder_dialog;
 static GtkWidget *new_folder_entry;
@@ -60,15 +54,6 @@ static void transfer_from_jukebox_to_hd (GtkButton *button,
   if (metalist != NULL) {
     GtkWidget *label1, *label2, *dialog, *button, *separator;
 
-#if !GTK_CHECK_VERSION(2,6,0)    
-    dialog = gnome_dialog_new(_("Transferring tracks from jukebox library"),
-			      GNOME_STOCK_BUTTON_CANCEL,
-			      NULL);
-    gnome_dialog_button_connect(GNOME_DIALOG(dialog),
-				0,
-				G_CALLBACK(cancel_jukebox_operation_click),
-				NULL);
-#else
     dialog=gtk_dialog_new_with_buttons(_("Transferring tracks from jukebox library"),
 		    NULL,
 		    0,
@@ -79,9 +64,7 @@ static void transfer_from_jukebox_to_hd (GtkButton *button,
     g_signal_connect(button,
 		    "clicked",
 		    G_CALLBACK(cancel_jukebox_operation_click),
-		    NULL);  
-#endif
-    
+		    NULL);
     g_signal_connect_object(GTK_OBJECT(dialog),
 			    "delete_event",
 			    G_CALLBACK(gtk_widget_destroy),
@@ -92,10 +75,10 @@ static void transfer_from_jukebox_to_hd (GtkButton *button,
     label2 = gtk_label_new("");
     progress_bar = gtk_progress_bar_new();
     separator = gtk_hseparator_new ();
-    gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(dialog)->vbox), label1, TRUE, TRUE, 0);
-    gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(dialog)->vbox), label2, TRUE, TRUE, 0);
-    gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(dialog)->vbox), separator, TRUE, TRUE, 0);
-    gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(dialog)->vbox), progress_bar, TRUE, TRUE, 0);
+    gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox), label1, TRUE, TRUE, 0);
+    gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox), label2, TRUE, TRUE, 0);
+    gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox), separator, TRUE, TRUE, 0);
+    gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox), progress_bar, TRUE, TRUE, 0);
     gtk_widget_show_all(dialog);
 
     jb2hd_thread_args->dialog = dialog;
@@ -113,14 +96,14 @@ static GList *get_files_to_xfer(GList *metalist, GList *appendum) {
   GList *templist = g_list_first(metalist);
 
   while (templist != NULL) {
-    
+
     metadata_t *meta = (metadata_t *) templist->data;
     gchar *file = filename_fromutf8(meta->path);
-    
+
     if(is_directory(file)) {
       /* Do not recurse into . and .. */
       if(get_prefs_recurse_dir()
-	 && strcmp(meta->artist,"..") 
+	 && strcmp(meta->artist,"..")
 	 && strcmp(meta->artist,".") ) {
 	GList *inner_metalist;
 
@@ -159,15 +142,6 @@ void transfer_from_hd_to_jukebox(GList *playlists)
     GtkWidget *label1, *label2, *dialog, *button, *separator;
 
     hd2jb_thread_args = (hd2jb_thread_arg_t *) malloc(sizeof (hd2jb_thread_arg_t));
-#if !GTK_CHECK_VERSION(2,6,0)
-    dialog = gnome_dialog_new(_("Transferring tracks to jukebox library"),
-			      GNOME_STOCK_BUTTON_CANCEL,
-			      NULL);
-    gnome_dialog_button_connect(GNOME_DIALOG(dialog),
-				0,
-				G_CALLBACK(cancel_jukebox_operation_click),
-				NULL);
-#else
      dialog=gtk_dialog_new_with_buttons(_("Transferring tracks to jukebox library"),
 		    NULL,
 		    0,
@@ -178,8 +152,7 @@ void transfer_from_hd_to_jukebox(GList *playlists)
     g_signal_connect(button,
 		    "clicked",
 		    G_CALLBACK(cancel_jukebox_operation_click),
-		    NULL);     
-#endif
+		    NULL);
     g_signal_connect_object(GTK_OBJECT(dialog),
 			    "delete_event",
 			    G_CALLBACK(gtk_widget_destroy),
@@ -191,17 +164,17 @@ void transfer_from_hd_to_jukebox(GList *playlists)
     label2 = gtk_label_new("");   /* FIXME: Instead add a list to the dialog so progress may be seen better */
     progress_bar = gtk_progress_bar_new();
     separator = gtk_hseparator_new ();
-    gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(dialog)->vbox), label1, TRUE, TRUE, 0);
-    gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(dialog)->vbox), label2, TRUE, TRUE, 0);
-    gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(dialog)->vbox), separator, TRUE, TRUE, 0);
-    gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(dialog)->vbox), progress_bar, TRUE, TRUE, 0);
+    gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox), label1, TRUE, TRUE, 0);
+    gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox), label2, TRUE, TRUE, 0);
+    gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox), separator, TRUE, TRUE, 0);
+    gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox), progress_bar, TRUE, TRUE, 0);
     gtk_widget_show_all(dialog);
-    
+
     hd2jb_thread_args->dialog = dialog;
     hd2jb_thread_args->label = label2;
     xferlist = get_files_to_xfer(metalist, NULL);
-    destroy_metalist(metalist);    
- 
+    destroy_metalist(metalist);
+
     hd2jb_thread_args->metalist = xferlist;
     hd2jb_thread_args->pltreestore = playlist_widgets.pltreestore;
     hd2jb_thread_args->playlists = playlists;
@@ -231,29 +204,66 @@ void transfer_from_hd_to_jukebox(GList *playlists)
  * Other tool functions for popup choices etc.
  *****************************************************************************/
 
-static void add_to_history (gchar *string)
+#define MAX_HISTORY 10
+
+static void add_to_history(gchar *string)
 {
   /* See if the string is already in the history */
   GList *history = transfer_widgets.history;
-  while (history)
-    {
-      if (!strcmp(history->data, string))
-	  return;
-      history = g_list_next(history);
-    }
+  while (history) {
+    if (!strcmp(history->data, string))
+      return;
+    history = g_list_next(history);
+  }
   history = transfer_widgets.history;
   /* Else add it */
   transfer_widgets.history
     = g_list_prepend (transfer_widgets.history, string);
-  /* Do not remember more than 5 strings */
-  while (g_list_length(history) > 5)
-    {
+  /* Do not remember more than MAX_HISTORY strings */
+  while (g_list_length(history) > MAX_HISTORY) {
       GList *elem;
 
       elem = g_list_last(history);
       transfer_widgets.history
 	= g_list_remove(history, elem->data);
+  }
+}
+
+static void set_popup_history(GtkWidget *combo)
+{
+  GList *history = transfer_widgets.history;
+
+#if GTK_CHECK_VERSION(3,0,0)
+  // Use the new combobox abstractions in 3.0 and later
+  gtk_combo_box_text_remove_all(GTK_COMBO_BOX_TEXT(combo));
+  while (history) {
+    gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(combo), history->data);
+    history = g_list_next(history);
+  }
+#else
+  // Dead ugly code for older GTK
+  static gboolean firstrun = TRUE;
+  int i;
+
+  // Blank out all 5 entries
+  if (!firstrun) {
+    for (i = 0; i < MAX_HISTORY; i++) {
+      gtk_combo_box_remove_text(GTK_COMBO_BOX(combo), 0);
     }
+  } else {
+    firstrun = FALSE;
+  }
+
+  for (i = 0; i < MAX_HISTORY; i++) {
+    if (history) {
+      gtk_combo_box_append_text(GTK_COMBO_BOX(combo), history->data);
+      history = g_list_next(history);
+    } else {
+      gtk_combo_box_append_text(GTK_COMBO_BOX(combo), "");
+    }
+    i++;
+  }
+#endif
 }
 
 
@@ -322,54 +332,38 @@ static GCallback create_new_folder_ok_button (GtkButton *button,
 static GCallback hdmenu_new_folder_response(gpointer data)
 {
   GtkWidget *label, *button;
-#if !GTK_CHECK_VERSION(2,6,0)  
-  // Here we use libgnomeui instead.
-  new_folder_dialog = gnome_dialog_new(_("New folder"),
-				   GNOME_STOCK_BUTTON_CANCEL,
-				   GNOME_STOCK_BUTTON_OK,
-				   NULL);
-  gnome_dialog_button_connect_object(GNOME_DIALOG(new_folder_dialog),
-				     0,
-				     GTK_SIGNAL_FUNC(gtk_widget_destroy),
-				     GTK_OBJECT(new_folder_dialog));
-  gnome_dialog_button_connect(GNOME_DIALOG(new_folder_dialog),
-			      1,
-			      GTK_SIGNAL_FUNC(create_new_folder_ok_button),
-			      NULL);
-#else
+
   new_folder_dialog=gtk_dialog_new_with_buttons(_("New folder"),
-					    NULL, 
-					    0, 
+					    NULL,
+					    0,
 					    NULL);
 
-  button = gtk_dialog_add_button(GTK_DIALOG(new_folder_dialog), 
-				 GTK_STOCK_CANCEL, 
+  button = gtk_dialog_add_button(GTK_DIALOG(new_folder_dialog),
+				 GTK_STOCK_CANCEL,
 				 0);
-  g_signal_connect(button, 
-		   "clicked", 
-		   GTK_SIGNAL_FUNC(dispose_of_dialog_window), 
+  g_signal_connect(button,
+		   "clicked",
+		   G_CALLBACK(dispose_of_dialog_window),
 		   GTK_OBJECT(new_folder_dialog));
 
-  button = gtk_dialog_add_button(GTK_DIALOG(new_folder_dialog), 
-				 GTK_STOCK_OK, 
+  button = gtk_dialog_add_button(GTK_DIALOG(new_folder_dialog),
+				 GTK_STOCK_OK,
 				 1);
-  g_signal_connect(button, 
-		   "clicked", 
-		   GTK_SIGNAL_FUNC(create_new_folder_ok_button), 
+  g_signal_connect(button,
+		   "clicked",
+		   G_CALLBACK(create_new_folder_ok_button),
 		   NULL);
-#endif
-        
-  
+
   gtk_window_set_position (GTK_WINDOW(new_folder_dialog), GTK_WIN_POS_MOUSE);
 
   label = gtk_label_new(_("Enter a name for the folder:"));
-  gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(new_folder_dialog)->vbox), label, TRUE, TRUE, 0);
+  gtk_box_pack_start(GTK_BOX(GTK_DIALOG(new_folder_dialog)->vbox), label, TRUE, TRUE, 0);
   gtk_widget_show(label);
   new_folder_entry = gtk_entry_new();
-  gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(new_folder_dialog)->vbox), new_folder_entry, TRUE, TRUE, 0);
+  gtk_box_pack_start(GTK_BOX(GTK_DIALOG(new_folder_dialog)->vbox), new_folder_entry, TRUE, TRUE, 0);
   gtk_widget_show(new_folder_entry);
 
-  g_signal_connect(G_OBJECT (new_folder_dialog), 
+  g_signal_connect(G_OBJECT (new_folder_dialog),
 		   "delete_event",
 		   G_CALLBACK(gtk_widget_destroy),
 		   G_OBJECT (new_folder_dialog));
@@ -389,7 +383,8 @@ static void go_down(void)
     return;
   }
 
-  /* Get the size column. If this is zero, 
+  /*
+   * Get the size column. If this is zero,
    * we're dealing with a directory! Only
    * directories of size 0 are allowed, no
    * files of size 0.
@@ -400,14 +395,14 @@ static void go_down(void)
     change_directory(meta->path);
     path = get_current_dir();
     // Set the text in the box, then switch directory view
-    gtk_combo_set_popdown_strings (GTK_COMBO (combo), transfer_widgets.history);
-    gtk_entry_set_text (GTK_ENTRY (GTK_COMBO (combo)->entry), path);
+    set_popup_history(combo);
+    gtk_entry_set_text(GTK_ENTRY(gtk_bin_get_child(GTK_BIN(combo))), path);
     fill_in_dir(HD_LIST, path);
   }
   destroy_metadata_t(meta);
 }
 
-/* If we come here, then the user has selected a row in the 
+/* If we come here, then the user has selected a row in the
  * harddisk file listing */
 static GCallback hdlist_mouseevent (GtkWidget      *widget,
 				    GdkEventButton *event,
@@ -419,7 +414,7 @@ static GCallback hdlist_mouseevent (GtkWidget      *widget,
     return (gpointer) 1;
   } else if (event->type == GDK_BUTTON_PRESS && event->button == 3) {
     GdkEventButton *bevent = (GdkEventButton *) event;
-    gtk_menu_popup (GTK_MENU (transfer_widgets.harddiskpopupmenu), 
+    gtk_menu_popup (GTK_MENU (transfer_widgets.harddiskpopupmenu),
 		    NULL, NULL, NULL, NULL, bevent->button, bevent->time);
     return (gpointer) 1;
   }
@@ -430,7 +425,7 @@ static GCallback hdlist_keyevent (GtkWidget    *widget,
 				  GdkEventKey    *event,
 				  gpointer        data )
 {
-  if (event->type == GDK_KEY_PRESS && 
+  if (event->type == GDK_KEY_PRESS &&
       (event->keyval == GDK_Return || event->keyval == GDK_KP_Enter)) {
     go_down();
     return (gpointer) 1;
@@ -501,11 +496,16 @@ static GCallback jblist_mouseevent (GtkWidget      *clist,
   return data;
 }
 
-static int chdir_edit (GtkWidget * widget, gpointer data)
+static int chdir_edit(GtkWidget * widget, gpointer data)
 {
   gchar *text, *tempstr, *path;
 
-  text = (gchar *) gtk_entry_get_text (GTK_ENTRY (GTK_COMBO (transfer_widgets.combo)->entry));
+#if GTK_CHECK_VERSION(2,24,0)
+  text = (gchar *) gtk_combo_box_text_get_active_text(GTK_COMBO_BOX_TEXT(transfer_widgets.combo));
+#else
+  text = (gchar *) gtk_combo_box_get_active_text(GTK_COMBO_BOX(transfer_widgets.combo));
+#endif
+
   if ((tempstr = expand_path (text)) == NULL) {
     g_free (tempstr);
   } else
@@ -518,8 +518,8 @@ static int chdir_edit (GtkWidget * widget, gpointer data)
   change_directory(text);
   /* Set the text in the box, then switch directory view */
   path = get_current_dir();
-  gtk_combo_set_popdown_strings(GTK_COMBO(transfer_widgets.combo), transfer_widgets.history);
-  gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(transfer_widgets.combo)->entry), path);
+  set_popup_history(transfer_widgets.combo);
+  gtk_entry_set_text(GTK_ENTRY(gtk_bin_get_child(GTK_BIN(transfer_widgets.combo))), path);
   fill_in_dir(HD_LIST, path);
   return (FALSE);
 }
@@ -534,14 +534,14 @@ static void cell_data_func (GtkTreeViewColumn *tree_column,
   metadata_t *meta = get_metadata_from_model(model, iter);
   if (meta->size == 0) {
     g_object_set(G_OBJECT(cell),
-		 "foreground", GNOMAD_DIRECTORY_FOLDER_ENTRY_COLOR, 
+		 "foreground", GNOMAD_DIRECTORY_FOLDER_ENTRY_COLOR,
 		 "weight", GNOMAD_DIRECTORY_FOLDER_ENTRY_WEIGHT,
 		 "style", GNOMAD_DIRECTORY_FOLDER_ENTRY_STYLE,
 		 "underline", PANGO_UNDERLINE_SINGLE,
 		 NULL);
   } else {
     g_object_set(G_OBJECT(cell),
-		 "foreground", GNOMAD_DIRECTORY_FILE_ENTRY_COLOR, 
+		 "foreground", GNOMAD_DIRECTORY_FILE_ENTRY_COLOR,
 		 "weight", GNOMAD_DIRECTORY_FILE_ENTRY_WEIGHT,
 		 "style", GNOMAD_DIRECTORY_FILE_ENTRY_STYLE,
 		 "underline", FALSE,
@@ -580,20 +580,20 @@ static GtkWidget *create_listview(GtkListStore *liststore)
   */
   listview = gtk_tree_view_new_with_model (GTK_TREE_MODEL(liststore));
   gtk_tree_view_set_rules_hint(GTK_TREE_VIEW(listview), TRUE);
-  
+
   dirtextrenderer = gtk_cell_renderer_text_new();
   textrenderer = gtk_cell_renderer_text_new();
   /* This renderer render time measures */
   timerenderer = gtk_cell_renderer_text_new();
 
   g_object_set(G_OBJECT(textrenderer),
-	       "foreground", GNOMAD_DIRECTORY_FILE_ENTRY_COLOR, 
+	       "foreground", GNOMAD_DIRECTORY_FILE_ENTRY_COLOR,
 	       "weight", GNOMAD_DIRECTORY_FILE_ENTRY_WEIGHT,
 	       "style", GNOMAD_DIRECTORY_FILE_ENTRY_STYLE,
 	       "underline", FALSE,
 	       NULL);
   g_object_set(G_OBJECT(timerenderer),
-	       "foreground", GNOMAD_DIRECTORY_FILE_ENTRY_COLOR, 
+	       "foreground", GNOMAD_DIRECTORY_FILE_ENTRY_COLOR,
 	       "weight", GNOMAD_DIRECTORY_FILE_ENTRY_WEIGHT,
 	       "style", GNOMAD_DIRECTORY_FILE_ENTRY_STYLE,
 	       "underline", FALSE,
@@ -769,9 +769,9 @@ GtkWidget *create_xfer_widgets(void)
 
   transfer_widgets.history = NULL;
   /* Just add something to the history... */
-  transfer_widgets.history = 
+  transfer_widgets.history =
     g_list_append (transfer_widgets.history, (gpointer) get_current_dir());
-  
+
   /* The popup menu for the harddisk files */
   popupmenu = gtk_menu_new ();
   popupmenu_item  = gtk_menu_item_new_with_label (_("Rescan directory metadata"));
@@ -867,24 +867,30 @@ GtkWidget *create_xfer_widgets(void)
 			  0);
   gtk_widget_show (popupmenu_item);
   transfer_widgets.jukeboxpopupmenu = popupmenu;
-  
+
   /* Then the panel (handle in the middle) */
-  music_panel = gtk_hpaned_new ();
-  leftbox = gtk_hbox_new (FALSE, 0);
-  left_vbox=gtk_vbox_new(FALSE, 0);
-  combo = gtk_combo_new ();
+  music_panel = gtk_hpaned_new();
+  leftbox = gtk_hbox_new(FALSE, 0);
+  left_vbox = gtk_vbox_new(FALSE, 0);
+
+#if GTK_CHECK_VERSION(2,24,0)
+  // Use the new combo box type in 2.24 and later
+  combo = gtk_combo_box_text_new_with_entry();
+#else
+  combo = gtk_combo_box_entry_new_text();
+#endif
+
   transfer_widgets.combo = combo;
-  gtk_combo_set_case_sensitive (GTK_COMBO (combo), 1);
-  gtk_combo_set_popdown_strings (GTK_COMBO (combo), transfer_widgets.history);
+  set_popup_history(combo);
   gtk_box_pack_start(GTK_BOX(left_vbox), combo, FALSE, FALSE, 0);
-  g_signal_connect_object(GTK_OBJECT(GTK_COMBO(combo)->entry),
+  // signal "changed" on the combo directly will not work
+  g_signal_connect_object(GTK_OBJECT(gtk_bin_get_child(GTK_BIN(combo))),
 			  "activate",
 			  G_CALLBACK(chdir_edit),
 			  NULL,
 			  0);
-  gtk_combo_disable_activate (GTK_COMBO (combo));
-  gtk_entry_set_text (GTK_ENTRY (GTK_COMBO (combo)->entry), get_current_dir());
-  gtk_widget_show (combo);
+  gtk_entry_set_text(GTK_ENTRY(gtk_bin_get_child(GTK_BIN(combo))), get_current_dir());
+  gtk_widget_show(combo);
 
   /* Create the stores and their views */
   hdlistview = create_listview(transfer_widgets.hdliststore);
@@ -914,25 +920,29 @@ GtkWidget *create_xfer_widgets(void)
 			  0);
 
   /* Fill in and sort directory */
-  fill_in_dir(HD_LIST, (gchar *) gtk_entry_get_text(GTK_ENTRY (GTK_COMBO (combo)->entry)));
+#if GTK_CHECK_VERSION(2,24,0)
+  fill_in_dir(HD_LIST, (gchar *) gtk_combo_box_text_get_active_text(GTK_COMBO_BOX_TEXT(combo)));
+#else
+  fill_in_dir(HD_LIST, (gchar *) gtk_combo_box_get_active_text(GTK_COMBO_BOX(combo)));
+#endif
   view_and_sort_list_store(HD_LIST);
 
   /* Create a scrolled window for the harddisk files */
   scrolled_window = gtk_scrolled_window_new (NULL, NULL);
   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_window),
                                     GTK_POLICY_AUTOMATIC, GTK_POLICY_ALWAYS);
-  
+
   gtk_container_add(GTK_CONTAINER(scrolled_window), hdlistview);
   gtk_widget_show(hdlistview);
   gtk_box_pack_start(GTK_BOX(left_vbox), scrolled_window, TRUE, TRUE, 0);
   gtk_widget_show (scrolled_window);
   gtk_widget_show(left_vbox);
   gtk_box_pack_start(GTK_BOX(leftbox), left_vbox, TRUE, TRUE, 0);
-  
+
   /* A vertical box for the transfer buttons */
   transfer_button_vbox=gtk_vbox_new(FALSE, 0);
   gtk_container_set_border_width(GTK_CONTAINER(transfer_button_vbox), 5);
-  
+
   /* Add buttons to this vertical box */
   button = gtk_button_new();
   arrow = gtk_arrow_new(GTK_ARROW_RIGHT, GTK_SHADOW_NONE);
@@ -956,12 +966,12 @@ GtkWidget *create_xfer_widgets(void)
 			  0);
   gtk_box_pack_start(GTK_BOX(transfer_button_vbox), button, TRUE, FALSE, 0);
   gtk_widget_show(button);
-  
+
   gtk_box_pack_start(GTK_BOX(leftbox), transfer_button_vbox, FALSE, FALSE, 0);
   gtk_paned_pack1 (GTK_PANED(music_panel), leftbox, TRUE, TRUE);
   gtk_widget_show(leftbox);
   gtk_widget_show(transfer_button_vbox);
-  
+
 
   /* A vertical box for jukebox scroll and label */
   right_vbox=gtk_vbox_new(FALSE, 0);
@@ -969,7 +979,7 @@ GtkWidget *create_xfer_widgets(void)
   scrolled_window = gtk_scrolled_window_new (NULL, NULL);
   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_window),
 				  GTK_POLICY_AUTOMATIC, GTK_POLICY_ALWAYS);
-  
+
   /* Add the CList widget to the vertical box and show it. */
   gtk_container_add(GTK_CONTAINER(scrolled_window), jblistview);
   gtk_widget_show(jblistview);
