@@ -20,6 +20,6 @@ Boston, MA 02111-1307, USA.
 #define XFERH_INCLUDED 1
 
 void transfer_from_hd_to_jukebox(GList *playlists);
-GtkWidget *create_xfer_widgets();
+GtkWidget *create_xfer_widgets(void);
 
 #endif
